# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    p.county("Harju", "")
    p.town("Tallinn", "")
    p.town("Loksa", "")
    p.municipality("Vasalemma", "")
    p.smallborough("Rummu", "")
    p.village("Veskiküla", "")
    p.smallborough("Ämari", "")
    p.village("Lemmaru", "76107")

    p.municipality("Nissi", "")
    p.smallborough("Turba", "")
    p.village("Lehetu", "")
    p.village("Madila", "")
    p.smallborough("Riisipere", "")
    p.village("Kivitammi", "76207")
    p.village("Mustu", "76216")
    p.village("Lepaste", "76217")
    p.village("Tabara", "")
    p.village("Viruküla", "76206")
    p.village("Odulemma", "76210")
    p.village("Ellamaa", "76203")
    p.village("Jaanika", "76211")
    p.village("Aude", "76209")
    p.village("Rehemäe", "76218")
    p.village("Ürjaste", "76214")
    p.village("Siimika", "76208")
    p.village("Nurme", "76215")
    p.village("Vilumäe", "76212")
    p.village("Munalaskme", "76318")

    p.municipality("Saku", "")
    p.village("Tänassilma", "")
    p.village("Üksnurme", "")
    p.village("Rahula", "")
    p.village("Roobuka", "")
    p.village("Jälgimäe", "")
    p.village("Kirdalu", "")
    p.village("Kasemetsa", "")
    p.village("Männiku", "")
    p.village("Tagadi", "")
    p.village("Kurtna", "")
    p.village("Metsanurme", "")
    p.smallborough("Kiisa", "")
    p.village("Juuliku", "")
    p.village("Tammejärve", "")
    p.village("Kanama", "")
    p.village("Saustinõmme", "")
    p.village("Tõdva", "")
    p.village("Lokuti", "")
    p.village("Tammemäe", "75509")
    p.village("Kajamaa", "75504")
    p.village("Sookaera-Metsanurga", "75515")

    p.town("Saue", "")
    p.smallborough("Laagri", "")
    p.village("Aila", "")
    p.village("Alliku", "")
    p.village("Ääsmäe", "")
    p.village("Vatsla", "")
    p.village("Hüüru", "")
    p.village("Vanamõisa", "")
    p.village("Jõgisoo", "")
    p.village("Püha", "")
    p.village("Maidla", "")
    p.village("Valingu", "")
    p.village("Koppelmaa", "")
    p.village("Tuula", "")
    p.village("Pällu", "")
    p.village("Kiia", "")
    p.village("Tagametsa", "76409")
    p.village("Pärinurme", "76408")
    p.village("Koidu", "76418")

    p.municipality("Viimsi", "")
    p.village("Püünsi", "")
    p.village("Pringi", "")
    p.village("Muuga", "")
    p.smallborough("Haabneeme", "")
    p.village("Laiaküla", "")
    p.village("Lubja", "")
    p.village("Rohuneeme", "")
    p.village("Pärnamäe", "")
    p.village("Tammneeme", "")
    p.village("Leppneeme", "")
    p.village("Metsakasti", "")
    p.village("Randvere", "")
    p.village("Miiduranna", "")
    p.village("Kelvingi", "")
    p.village("Äigrumäe", "")
    p.village("Kelnase", "")
    p.village("Lõunaküla/Storbyn", "74022")
    p.village("Tagaküla/Bakbyn", "74023")
    p.village("Lääneotsa", "74007")
    p.village("Väikeheinamaa/Lillängin", "74024")
    p.village("Idaotsa", "74005")

    p.municipality("Raasiku", "")
    p.smallborough("Aruküla", "")
    p.village("Kurgla", "")
    p.village("Kalesi", "")
    p.village("Kiviloo", "")
    p.village("Perila", "")
    p.village("Peningi", "")
    p.village("Igavere", "")
    p.village("Kulli", "")
    p.village("Rätla", "75216")
    p.village("Järsi", "75204")
    p.village("Pikavere", "75202")
    p.village("Härma", "75214")
    p.village("Tõhelgi", "75223")
    p.village("Mallavere", "75210")

    p.municipality("Jõelähtme", "")
    p.smallborough("Loo", "")
    p.village("Jägala", "")
    p.village("Kaberneeme", "")
    p.village("Liivamäe", "")
    p.village("Neeme", "")
    p.village("Manniva", "")
    p.village("Uusküla", "")
    p.village("Ülgase", "")
    p.village("Ihasalu", "")
    p.village("Kallavere", "")
    p.smallborough("Kostivere", "")
    p.village("Iru", "")
    p.village("Haljava", "")
    p.village("Koogi", "")
    p.village("Saviranna", "")
    p.village("Saha", "")
    p.village("Rebala", "")
    p.village("Ruu", "")
    p.village("Koipsi", "74215")
    p.village("Rammu", "74227")
    p.village("Aruaru", "75225")
    p.village("Võerdla", "74221")
    p.village("Vandjala", "74229")
    p.village("Sambu", "75222")
    p.village("Rohusi", "74219")
    p.village("Kullamäe", "74218")
    p.village("Kostiranna", "74225")
    p.village("Parasmäe", "74230")
    p.village("Nehatu", "74208")
    p.village("Koila", "74214")

    p.town("Maardu", "")
    p.municipality("Rae", "")
    p.smallborough("Vaida", "")
    p.smallborough("Jüri", "")
    p.village("Patika", "")
    p.village("Lehmja", "")
    p.village("Vaskjala", "")
    p.village("Järveküla", "")
    p.village("Aaviku", "")
    p.village("Pajupea", "")
    p.village("Tuulevälja", "")
    p.smallborough("Peetri", "")
    p.smallborough("Lagedi", "")
    p.village("Karla", "")
    p.village("Pildiküla", "")
    p.village("Soodevahe", "")
    p.village("Kadaka", "")
    p.village("Ülejõe", "")
    p.village("Suuresta", "")
    p.smallborough("Assaku", "")
    p.village("Veskitaguse", "")
    p.village("Suursoo", "")
    p.village("Veneküla", "")
    p.village("Kurna", "")
    p.village("Kopli", "")
    p.village("Urvaste", "")
    p.village("Salu", "")
    p.village("Limu", "")
    p.village("Vaidasoo", "")
    p.village("Seli", "75311")
    p.village("Kautjala", "75315")
    p.village("Aruvalla", "75320")

    p.municipality("Harku", "")
    p.smallborough("Tabasalu", "")
    p.village("Adra", "")
    p.village("Liikva", "")
    p.village("Tiskre", "")
    p.village("Naage", "")
    p.village("Ilmandu", "")
    p.village("Muraste", "")
    p.village("Suurupi", "")
    p.village("Harkujärve", "")
    p.village("Rannamõisa", "")
    p.village("Viti", "")
    p.village("Türisalu", "")
    p.village("Kumna", "")
    p.village("Laabi", "")
    p.village("Tutermaa", "")
    p.village("Sõrve", "")
    p.village("Kütke", "")
    p.village("Vaila", "")
    p.village("Vääna", "")
    p.village("Vääna-Jõesuu", "")
    p.village("Vahi", "")
    p.village("Humala", "76707")

    p.municipality("Keila", "")
    p.village("Kloogaranna", "")
    p.smallborough("Klooga", "")
    p.village("Lehola", "")
    p.village("Maeru", "")
    p.village("Laulasmaa", "")
    p.village("Ohtu", "")
    p.village("Kulna", "")
    p.village("Illurma", "")
    p.village("Tuulna", "")
    p.village("Meremõisa", "")
    p.village("Valkse", "")
    p.smallborough("Keila-Joa", "")
    p.smallborough("Karjaküla", "")
    p.village("Lohusalu", "")
    p.village("Käesalu", "")
    p.village("Niitvälja", "")
    p.village("Tõmmiku", "76619")
    p.village("Laoküla", "76714")
    p.village("Nahkjala", "76104")
    p.village("Põllküla", "76712")
    p.village("Keelva", "76622")

    p.municipality("Anija", "")
    p.town("Kehra", "")
    p.village("Lükati", "")
    p.village("Alavere", "")
    p.village("Mustjõe", "")
    p.village("Pillapalu", "")
    p.village("Lehtmetsa", "")
    p.village("Kuusemäe", "")
    p.village("Soodla", "")
    p.village("Parila", "75221")
    p.village("Aavere", "74417")
    p.village("Paasiku", "74314")
    p.village("Salumetsa", "74312")
    p.village("Kihmla", "75219")
    p.village("Looküla", "74311")
    p.village("Rasivere", "74403")
    p.village("Voose", "74410")
    p.village("Linnakse", "75220")
    p.village("Arava", "74405")
    p.village("Partsaare", "74415")
    p.village("Uuearu", "74407")
    p.village("Salumäe", "75226")
    p.village("Kaunissaare", "74309")
    p.village("Vetla", "74408")
    p.village("Pikva", "")
    p.village("Raudoja", "74416")
    p.village("Rooküla", "74404")
    p.village("Härmakosu", "74412")
    p.village("Lilli", "74414")

    p.municipality("Kiili", "")
    p.smallborough("Luige", "")
    p.village("Sausti", "")
    p.smallborough("Kangru", "")
    p.village("Nabala", "")
    p.village("Sookaera", "")
    p.village("Vaela", "")
    p.village("Lähtse", "")
    p.village("Mõisaküla", "")
    p.village("Sõgula", "75410")
    p.village("Kurevere", "75405")
    p.village("Paekna", "75408")
    p.village("Arusta", "75402")
    p.village("Piissoo", "75414")

    p.town("Paldiski", "")
    p.municipality("Kose", "")
    p.smallborough("Kose-Uuemõisa", "")
    p.village("Oru", "")
    p.village("Tade", "")
    p.village("Liiva", "")
    p.smallborough("Ravila", "")
    p.village("Tuhala", "")
    p.village("Saula", "")
    p.village("Ahisilla", "")
    p.village("Krei", "")
    p.village("Palvere", "")
    p.village("Vardja", "")
    p.village("Nõmbra", "")
    p.village("Viskla", "")
    p.village("Sõmeru", "")
    p.village("Tammiku", "75119")
    p.village("Nõrava", "75116")
    p.village("Raveliku", "75112")
    p.village("Vilama", "75110")
    p.village("Kata", "75120")
    p.village("Kolu", "75121")
    p.village("Kuivajõe", "75123")
    p.village("Võlle", "75109")
    p.village("Kanavere", "75105")

    p.municipality("Padise", "")
    p.village("Madise", "")
    p.village("Kurkse", "")
    p.village("Harju-Risti", "")
    p.village("Kõmmaste", "76016")
    p.village("Keibu", "76019")
    p.village("Vintse", "76021")
    p.village("Alliklepa", "76018")
    p.village("Määra", "76010")
    p.village("Vihterpalu", "76003")
    p.village("Audevälja", "76005")
    p.village("Altküla", "76012")
    p.village("Vilivalla", "76020")
    p.village("Pae", "76015")
    p.village("Hatu", "76013")
    p.village("Metslõugu", "76009")
    p.village("Langa", "76711")
    p.village("Laane", "")
    p.village("Kasepere", "76007")
    p.village("Pedase", "76014")
    p.village("Änglema", "76022")
    p.village("Karilepa", "76006")
    p.village("Suurküla", "76011")
    p.village("Kobru", "76004")

    p.municipality("Kõue", "")
    p.smallborough("Ardu", "")
    p.smallborough("Habaja", "")
    p.village("Harmi", "75034")
    p.village("Virla", "75021")
    p.village("Paunaste", "75025")
    p.village("Aela", "75004")
    p.village("Katsina", "75005")
    p.village("Rõõsa", "75015")
    p.village("Kadja", "75003")
    p.village("Saarnakõrve", "75023")
    p.village("Kantküla", "75027")
    p.village("Vahetüki", "75020")
    p.village("Uueveski", "75037")
    p.village("Sae", "75016")
    p.village("Kukepala", "75010")
    p.village("Puusepa", "75017")
    p.village("Kõrvenurga", "75008")
    p.village("Kiruvere", "75006")
    p.village("Nutu", "75012")
    p.village("Alansi", "75035")
    p.village("Lutsu", "75030")
    p.village("Kirivalla", "75036")
    p.village("Paunküla", "75011")
    p.village("Riidamäe", "75032")
    p.village("Äksi", "75038")
    p.village("Silmsi", "75024")
    p.village("Ojasoo", "75031")
    p.village("Rava", "75014")
    p.village("Sääsküla", "75033")
    p.village("Lööra", "75028")
    p.village("Leistu", "75026")
    p.village("Marguse", "75029")
    p.village("Triigi", "75019")
    p.village("Nõmmeri", "75013")

    p.municipality("Kuusalu", "")
    p.smallborough("Kolga", "")
    p.smallborough("Kiiu", "")
    p.village("Valkla", "")
    p.village("Viinistu", "")
    p.village("Kaberla", "")
    p.village("Mäepea", "")
    p.village("Sõitme", "")
    p.village("Uuri", "")
    p.village("Mustametsa", "")
    p.village("Kolga-Aabla", "")
    p.village("Salmistu", "")
    p.village("Kiiu-Aabla", "")
    p.village("Vihasoo", "")
    p.village("Kõnnu", "")
    p.village("Allika", "")
    p.village("Leesi", "")
    p.village("Suurpea", "74812")
    p.village("Saunja", "74636")
    p.village("Valgejõe", "74712")
    p.village("Haavakannu", "74628")
    p.village("Nõmmeveski", "74815")
    p.village("Tapurla", "74721")
    p.village("Kemba", "74708")
    p.village("Kodasoo", "74632")
    p.village("Virve", "74814")
    p.village("Hirvli", "74607")
    p.village("Parksi", "74710")
    p.village("Tsitre", "74616")
    p.village("Tõreska", "74617")
    p.village("Koitjärve", "74622")
    p.village("Tammispea", "74715")
    p.village("Põhja", "74635")
    p.village("Muuksi", "74612")
    p.village("Suru", "74615")
    p.village("Kalme", "74714")
    p.village("Juminda", "74716")
    p.village("Pala", "")
    p.village("Kolgaküla", "74808")
    p.village("Tammistu", "74719")
    p.village("Hara", "74810")
    p.village("Pärispea", "74706")
    p.village("Liiapeksi", "74709")
    p.village("Pudisoo", "74626")
    p.village("Murksi", "74713")
    p.village("Joaveski", "74813")
    p.village("Kahala", "74621")
    p.village("Aru", "74606")
    p.village("Turbuneeme", "74707")
    p.village("Kursi", "74611")
    p.village("Pedaspea", "74718")
    p.village("Kolgu", "74618")
    p.village("Kasispea", "74811")
    p.village("Rehatse", "74624")
    p.village("Kosu", "74608")
    p.village("Vanaküla", "74711")
    p.village("Ilmastalu", "74619")
    p.village("Sigula", "74625")
    p.village("Kotka", "74809")
    p.village("Soorinna", "74614")
    p.village("Külmaallika", "74634")
    p.village("Kupu", "74610")

    p.municipality("Kernu", "")
    p.village("Laitse", "")
    p.village("Haiba", "")
    p.village("Ruila", "")
    p.village("Kustja", "")
    p.village("Mõnuste", "76310")
    p.village("Kirikla", "76306")
    p.village("Kabila", "")
    p.village("Metsanurga", "")
    p.village("Hingu", "76312")
    p.village("Kohatu", "76304")
    p.village("Muusika", "76309")

    p.municipality("Aegviidu", "")
    p.municipality("Kaasiku", "")
    p.municipality("Kibuna", "")
    p.municipality("Vahastu", "")
    p.municipality("Vansi", "")
    p.municipality("Vikipalu", "")
    p.municipality("Jägala-Joa", "")
    p.municipality("Kersalu", "")
    p.municipality("Haapse", "")
    p.municipality("Jõesuu", "")
    p.municipality("Pohla", "")
    p.municipality("Andineeme", "")




# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Viljandi (county)
    p.county("Viljandi", "")
    p.municipality("Suure-Jaani", "")
    p.village("Vastemõisa", "")
    p.village("Ülde", "")
    p.village("Võivaku", "")
    p.village("Reegoldi", "")
    p.village("Jälevere", "")
    p.village("Nuutre", "")
    p.smallborough("Olustvere", "")
    p.village("Lõhavere", "")
    p.village("Sürgavere", "")
    p.village("Päraküla", "")
    p.village("Tääksi", "")
    p.village("Kõidama", "")
    p.village("Kärevere", "70407")
    p.village("Karjasoo", "71408")
    p.village("Metsküla", "71302")
    p.village("Tällevere", "71511")
    p.village("Jaska", "70404")
    p.village("Ivaski", "71305")
    p.village("Kobruvere", "71306")
    p.village("Vihi", "71402")
    p.village("Mudiste", "70405")
    p.village("Kootsi", "71411")
    p.village("Mäeküla", "")
    p.village("Aimla", "70403")
    p.village("Navesti", "70406")
    p.village("Kurnuvere", "70412")
    p.village("Võhmassaare", "70606")
    p.village("Epra", "71405")
    p.village("Arjadi", "71505")
    p.village("Munsi", "71403")
    p.village("Ilbaku", "71307")
    p.village("Lahmuse", "71412")
    p.village("Ängi", "71507")
    p.village("Rääka", "71409")
    p.village("Taevere", "71510")
    p.village("Kildu", "71303")
    p.village("Sandra", "71309")
    p.village("Kibaru", "71506")
    p.village("Kuhjavere", "70414")
    p.village("Kuiavere", "70408")
    p.village("Paelama", "71308")
    p.village("Põhjaka", "71410")
    p.village("Kabila", "71404")
    p.village("Riiassaare", "70415")
    p.village("Kerita", "71406")
    p.village("Võlli", "71512")
    p.village("Lemmakõnnu", "71304")

    p.municipality("Abja", "")
    p.town("Abja-Paluoja", "")
    p.village("Veskimäe", "")
    p.village("Penuja", "")
    p.village("Abja-Vanamõisa", "")
    p.village("Põlde", "")
    p.village("Raamatu", "69308")
    p.village("Sarja", "69407")
    p.village("Atika", "69411")
    p.village("Saate", "69202")
    p.village("Veelikse", "69307")
    p.village("Umbsoo", "69309")
    p.village("Kamara", "69304")
    p.village("Räägu", "69310")
    p.village("Lasari", "69306")
    p.village("Laatre", "69305")
    p.village("Abjaku", "69410")

    p.town("Viljandi", "")
    p.town("Võhma", "")
    p.town("Mõisaküla", "")
    p.municipality("Viiratsi", "")
    p.village("Uusna", "")
    p.village("Vana-Võidu", "")
    p.village("Vardja", "")
    p.village("Tänassilma", "")
    p.village("Mähma", "")
    p.village("Jõeküla", "")
    p.village("Loime", "")
    p.village("Tõnuküla", "")
    p.village("Valma", "")
    p.village("Kibeküla", "69619")
    p.village("Saareküla", "70112")
    p.village("Vanavälja", "70114")
    p.village("Mäeltküla", "70105")
    p.village("Kuudeküla", "70111")
    p.village("Verilaske", "70110")
    p.village("Surva", "70115")
    p.village("Rebaste", "70117")
    p.village("Ridaküla", "70122")
    p.village("Vasara", "70107")
    p.village("Tusti", "70113")
    p.village("Ruudiküla", "70106")

    p.municipality("Halliste", "")
    p.village("Mõõnaste", "")
    p.village("Päidre", "")
    p.village("Kalvre", "")
    p.village("Hõbemäe", "69507")
    p.village("Ülemõisa", "69512")
    p.village("Maru", "69522")
    p.village("Naistevalla", "69519")
    p.smallborough("Õisu", "69502")
    p.village("Raja", "69503")
    p.village("Uue-Kariste", "69504")
    p.village("Vabamatsi", "69405")
    p.village("Rimmu", "69505")
    p.village("Mulgi", "69516")
    p.village("Pornuse", "69508")
    p.village("Kulla", "69509")
    p.village("Ereste", "69511")
    p.village("Saksaküla", "69520")
    p.village("Toosi", "69514")
    p.village("Päigiste", "69408")
    p.village("Kaarli", "69510")
    p.village("Tilla", "69517")
    p.village("Sammaste", "69521")
    p.village("Vana-Kariste", "69506")
    p.village("Niguli", "69515")

    p.municipality("Karksi", "")
    p.town("Karksi-Nuia", "")
    p.village("Kõvaküla", "")
    p.village("Morna", "")
    p.village("Univere", "")
    p.village("Polli", "")
    p.village("Lilli", "")
    p.village("Metsaküla", "69109")
    p.village("Hirmuküla", "69003")
    p.village("Leeli", "69106")
    p.village("Suuga", "71053")
    p.village("Muri", "71054")
    p.village("Sudiste", "69001")
    p.village("Ainja", "69105")
    p.village("Tuhalaane", "71056")
    p.village("Pärsi", "69110")
    p.village("Allaste", "69113")
    p.village("Äriküla", "69115")
    p.village("Pöögle", "69111")
    p.village("Oti", "69114")

    p.municipality("Kolga-Jaani", "")
    p.village("Leie", "")
    p.village("Parika", "70307")
    p.village("Eesnurga", "70306")
    p.village("Kaavere", "70318")
    p.village("Järtsaare", "70302")
    p.village("Oorgu", "70309")
    p.village("Odiste", "70308")
    p.village("Oiu", "70317")
    p.village("Vissuvere", "70311")
    p.village("Taganurga", "70310")
    p.village("Otiküla", "70316")
    p.village("Meleski", "70304")
    p.village("Vaibla", "70314")
    p.village("Lalsi", "70313")
    p.village("Lätkalu", "70315")

    p.municipality("Pärsti", "")
    p.village("Päri", "")
    p.village("Jämejala", "")
    p.smallborough("Ramsi", "")
    p.village("Kiisa", "")
    p.village("Vardi", "")
    p.village("Heimtali", "")
    p.village("Raudna", "")
    p.village("Rihkama", "")
    p.village("Puiatu", "")
    p.village("Mustivere", "")
    p.village("Matapera", "")
    p.village("Sinialliku", "")
    p.village("Pinska", "")
    p.village("Marna", "71108")
    p.village("Vanamõisa", "71119")
    p.village("Tõrreküla", "71111")
    p.village("Kookla", "71120")
    p.village("Savikoti", "71103")
    p.village("Kiini", "71125")
    p.village("Leemeti", "71122")
    p.village("Turva", "71112")
    p.village("Väike-Kõpu", "71124")
    p.village("Alustre", "71057")
    p.village("Laanekuru", "71107")
    p.village("Tohvri", "71114")
    p.village("Kingu", "71121")

    p.municipality("Tarvastu", "")
    p.village("Kärstna", "")
    p.smallborough("Mustla", "")
    p.village("Kivilõppe", "69706")
    p.village("Jakobimõisa", "69705")
    p.village("Porsa", "69710")
    p.village("Riuma", "69736")
    p.village("Pahuvere", "69725")
    p.village("Kalbuse", "69737")
    p.village("Vanausse", "69713")
    p.village("Pikru", "69709")
    p.village("Kuressaare", "69708")
    p.village("Maltsa", "69731")
    p.village("Muksi", "69724")
    p.village("Ülensi", "69720")
    p.village("Vilimeeste", "69718")
    p.village("Koidu", "69707")
    p.village("Raassilla", "69722")
    p.village("Põrga", "69726")
    p.village("Tinnikuru", "69716")
    p.village("Unametsa", "69717")
    p.village("Vooru", "69733")
    p.village("Villa", "69719")
    p.village("Järveküla", "69732")
    p.village("Metsla", "69711")
    p.village("Suislepa", "")
    p.village("Veisjärve", "69729")
    p.village("Väluste", "69704")
    p.village("Tagamõisa", "69727")
    p.village("Marjamäe", "69734")
    p.village("Roosilla", "69730")
    p.village("Mõnnaste", "69735")
    p.village("Ämmuste", "69721")
    p.village("Kannuküla", "69728")
    p.village("Anikatsi", "69723")
    p.village("Sooviku", "69714")

    p.municipality("Saarepeedi", "")
    p.village("Peetrimõisa", "")
    p.village("Võistre", "")
    p.village("Karula", "")
    p.village("Moori", "70211")
    p.village("Tõnissaare", "71069")
    p.village("Auksi", "71064")
    p.village("Välgita", "")
    p.village("Taari", "71072")
    p.village("Aindu", "71063")
    p.village("Kokaviidika", "71071")
    p.village("Tobraselja", "71068")

    p.municipality("Paistu", "")
    p.village("Sultsi", "")
    p.village("Loodi", "")
    p.village("Intsu", "")
    p.village("Holstre", "")
    p.village("Rebase", "69610")
    p.village("Pulleritsu", "69609")
    p.village("Luiga", "69606")
    p.village("Aidu", "69604")
    p.village("Tömbi", "69608")
    p.village("Viisuküla", "69607")
    p.village("Kassi", "71052")
    p.village("Mustapali", "69618")
    p.village("Pirmastu", "69620")
    p.village("Lolu", "69617")
    p.village("Hendrikumõisa", "69612")

    p.municipality("Kõpu", "")
    p.village("Tipu", "")
    p.village("Uia", "71206")
    p.village("Supsi", "71205")
    p.village("Iia", "71210")
    p.village("Vanaveski", "71207")
    p.village("Laane", "71202")
    p.village("Kuninga", "69518")
    p.village("Punaküla", "71204")
    p.village("Seruküla", "71203")

    p.municipality("Kõo", "")
    p.village("Soomevere", "")
    p.village("Paaksima", "70607")
    p.village("Koksvere", "70604")
    p.village("Saviaugu", "70503")
    p.village("Pilistvere", "70502")
    p.village("Maalasti", "70608")
    p.village("Kirivere", "70506")
    p.village("Unakvere", "70508")
    p.village("Arjassaare", "70507")
    p.village("Arussaare", "70605")
    p.village("Paenasti", "70509")
    p.village("Kangrussaare", "70505")
    p.village("Loopre", "70504")
    p.village("Venevere", "70511")

    p.municipality("Soe", "")




# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Võru (county)
    p.county("Võru", "")
    p.municipality("Vastseliina", "")
    p.village("Pari", "65258")
    p.village("Vana-Vastseliina", "65254")
    p.village("Lindora", "65224")
    p.village("Loosi", "65260")
    p.village("Plessi", "65328")
    p.village("Jeedasküla", "65212")
    p.village("Perametsa", "65234")
    p.village("Indra", "65259")
    p.village("Tsolli", "")
    p.village("Kerepäälse", "65217")
    p.village("Halla", "65204")
    p.village("Holsta", "65208")
    p.village("Raadi", "65237")
    p.village("Voki", "65257")
    p.village("Ortuma", "65231")
    p.village("Vatsa", "65255")
    p.village("Luhte", "65171")
    p.village("Kapera", "65216")
    p.village("Külaoru", "65223")
    p.village("Tellaste", "65247")
    p.village("Kõrve", "65221")
    p.village("Kündja", "65168")
    p.village("Tabina", "65246")
    p.village("Mutsu", "65226")
    p.village("Puutli", "65235")
    p.village("Kaagu", "65214")
    p.village("Kornitsa", "65219")
    p.village("Kirikumäe", "65218")
    p.village("Juraski", "65213")
    p.village("Heinasoo", "65205")
    p.village("Illi", "65210")
    p.village("Vana-Saaluse", "65253")
    p.village("Tallikeste", "65337")
    p.village("Viitka", "65256")
    p.village("Sutte", "65245")
    p.village("Kõo", "65165")
    p.village("Hinniala", "65206")
    p.village("Hinsa", "65207")
    p.village("Käpa", "65222")
    p.village("Saarde", "65239")
    p.village("Mäe-Kõoküla", "65227")

    p.town("Võru", "65620")
    p.smallborough("Väimela", "65566")
    p.smallborough("Parksepa", "65509")
    p.village("Võlsi", "")
    p.village("Roosisaare", "")
    p.village("Võrumõisa", "")
    p.village("Verijärve", "")
    p.village("Puiga", "")
    p.smallborough("Kose", "")
    p.village("Lompka", "65525")
    p.village("Sika", "")
    p.village("Hannuste", "65515")
    p.village("Käätso", "65524")
    p.village("Kusma", "65523")
    p.village("Nooska", "65531")
    p.village("Võrusoo", "65565")
    p.village("Kolepi", "65520")
    p.village("Vagula", "65553")
    p.village("Tagaküla", "65514")
    p.village("Kasaritsa", "65519")
    p.village("Väiso", "65503")
    p.village("Räpo", "65535")
    p.village("Umbsaare", "65538")
    p.village("Loosu", "65548")
    p.village("Juba", "65518")
    p.village("Mõisamäe", "65529")
    p.village("Palometsa", "65532")
    p.village("Vana-Nursi", "65540")
    p.village("Mõksi", "65530")
    p.village("Raiste", "65513")
    p.village("Tootsi", "65537")
    p.village("Meeliku", "65527")
    p.village("Kärnamäe", "65504")
    p.village("Lapi", "65505")
    p.village("Koloreino", "65521")

    p.town("Antsla", "")
    p.smallborough("Vana-Antsla", "")
    p.village("Tsooru", "")
    p.village("Säre", "")
    p.smallborough("Kobela", "")
    p.village("Kraavi", "66409")
    p.village("Kaika", "66421")
    p.village("Savilöövi", "66307")
    p.village("Anne", "66423")
    p.village("Antsu", "66424")
    p.village("Soome", "66415")
    p.village("Luhametsa", "66304")
    p.village("Madise", "66411")
    p.village("Oe", "66422")
    p.village("Kikkaoja", "66302")
    p.village("Taberlaane", "66417")
    p.village("Lusti", "66410")
    p.village("Litsmetsa", "66303")
    p.village("Mähkli", "66412")
    p.village("Jõepera", "66425")
    p.village("Ähijärve", "66420")
    p.village("Viirapalu", "66308")
    p.village("Haabsaare", "66405")
    p.village("Roosiku", "66306")
    p.village("Piisi", "66305")
    p.village("Kollino", "66408")
    p.village("Rimmi", "66414")

    p.municipality("Varstu", "")
    p.village("Punsa", "66107")
    p.village("Krabi", "66102")
    p.village("Vana-Roosa", "66109")
    p.village("Kangsti", "66103")
    p.village("Metstaga", "66106")
    p.village("Viru", "66309")
    p.village("Mutemetsa", "66114")
    p.village("Paganamaa", "66115")
    p.village("Hintsiko", "66110")
    p.village("Kõrgepalu", "66104")
    p.village("Laurimäe", "66111")
    p.village("Tagakolga", "66118")
    p.village("Harjuküla", "66120")
    p.village("Lüütsepa", "66113")
    p.village("Liguri", "66112")
    p.village("Soolätte", "66117")
    p.village("Raudsepa", "")
    p.village("Pähni", "66116")

    p.municipality("Sõmerpalu", "")
    p.village("Haava", "")
    p.village("Mustja", "66614")
    p.village("Leiso", "66634")
    p.village("Rummi", "66640")
    p.village("Udsali", "")
    p.village("Heeska", "66625")
    p.village("Kurenurme", "66631")
    p.village("Hargi", "66624")
    p.village("Mäekülä", "66615")
    p.village("Järvere", "66629")
    p.village("Linnamäe", "66635")
    p.village("Mustassaare", "66637")
    p.village("Horma", "66626")
    p.village("Pritsi", "66638")
    p.village("Haidaku", "66623")
    p.village("Osula", "66602")
    p.village("Majala", "66636")
    p.village("Hutita", "66627")
    p.village("Kärgula", "66632")
    p.village("Liiva", "66514")
    p.village("Kahro", "66617")
    p.village("Rauskapalu", "66639")
    p.village("Keema", "66511")
    p.village("Haamaste", "66616")
    p.village("Alakülä", "66620")
    p.village("Varese", "66642")
    p.village("Lakovitsa", "66633")
    p.village("Alapõdra", "66621")
    p.village("Punakülä", "66619")
    p.village("Lilli-Anne", "66613")
    p.village("Hänike", "66628")

    p.municipality("Rõuge", "")
    p.village("Hallimäe", "")
    p.village("Horsa", "")
    p.village("Kahru", "")
    p.village("Tüütsi", "66703")
    p.village("Rebäsemõisa", "66276")
    p.village("Pulli", "")
    p.village("Märdi", "66260")
    p.village("Laossaarõ", "66246")
    p.village("Savioru", "66285")
    p.village("Suurõ-Ruuga", "66292")
    p.village("Nilbõ", "66262")
    p.village("Vanamõisa", "66707")
    p.village("Tallima", "66293")
    p.village("Simmuli", "66288")
    p.village("Hapsu", "66214")
    p.village("Lauri", "66247")
    p.village("Sikalaanõ", "66287")
    p.village("Haki", "66209")
    p.village("Raudsepä", "66274")
    p.village("Soemõisa", "66290")
    p.village("Tiidu", "66296")
    p.village("Muhkamõtsa", "66255")
    p.village("Mõõlu", "66259")
    p.village("Kokõjüri", "66237")
    p.village("Kuuda", "66243")
    p.village("Kiidi", "66234")
    p.village("Möldri", "")
    p.village("Püssä", "66272")
    p.village("Kogrõ", "66235")
    p.village("Mikita", "")
    p.village("Vadsa", "66706")
    p.village("Viitina", "66711")
    p.village("Järvekülä", "66223")
    p.village("Hinu", "66217")
    p.village("Jugu", "66222")
    p.village("Kaugu", "66231")
    p.village("Soomõoru", "66291")
    p.village("Sandisuu", "66284")
    p.village("Matsi", "")
    p.village("Viliksaarõ", "66708")
    p.village("Nogu", "66263")
    p.village("Järvepalu", "66224")
    p.village("Rasva", "66273")
    p.village("Ahitsa", "66206")
    p.village("Väiku-Ruuga", "66709")
    p.village("Sadramõtsa", "66282")
    p.village("Handimiku", "66213")
    p.village("Augli", "66207")
    p.village("Aabra", "66205")
    p.village("Saarlasõ", "66281")
    p.village("Kurgjärve", "66241")
    p.village("Tilgu", "66297")
    p.village("Hansi", "65516")
    p.village("Toodsi", "")
    p.village("Rebäse", "")
    p.village("Kurvitsa", "66242")
    p.village("Hurda", "")
    p.village("Murdõmäe", "66257")
    p.village("Heedu", "66215")
    p.village("Muna", "66256")
    p.village("Tialasõ", "66295")
    p.village("Petrakuudi", "66267")
    p.village("Roobi", "66279")
    p.village("Kähri", "66244")
    p.village("Tsirgupalu", "66701")
    p.village("Nursi", "66712")
    p.village("Põru", "66271")
    p.village("Paaburissa", "66265")
    p.village("Utessuu", "66705")
    p.village("Karaski", "66229")
    p.village("Pugõstu", "66268")
    p.village("Kaluka", "66228")
    p.village("Sänna", "66710")
    p.village("Kolga", "66239")
    p.village("Tsutsu", "66702")
    p.village("Lutika", "66250")
    p.village("Paeboja", "66266")
    p.village("Põdra", "66270")
    p.village("Ruuksu", "66280")
    p.village("Kokõ", "66236")
    p.village("Kellämäe", "66233")
    p.village("Kavõldi", "66232")
    p.village("Saki", "66283")
    p.village("Kokõmäe", "66238")
    p.village("Heibri", "66216")
    p.village("Taudsa", "66294")
    p.village("Liivakupalu", "66248")
    p.village("Haabsilla", "66208")
    p.village("Kadõni", "66225")
    p.village("Ortumäe", "66264")
    p.village("Pärlijõe", "66211")
    p.village("Soekõrdsi", "66289")
    p.village("Tindi", "66298")
    p.village("Hotõmäe", "66218")
    p.village("Karba", "66230")
    p.village("Muduri", "66254")
    p.village("Kängsepä", "66245")
    p.village("Jaanipeebu", "66221")
    p.village("Lükkä", "66251")
    p.village("Kuklasõ", "66240")
    p.village("Härämäe", "66220")
    p.village("Riitsilla", "66277")
    p.village("Ristemäe", "66278")

    p.municipality("Mõniste", "")
    p.village("Hürova", "")
    p.village("Karisöödi", "66005")
    p.village("Koemetsa", "66006")
    p.village("Peebu", "66007")
    p.village("Parmupalu", "66015")
    p.village("Kallaste", "")
    p.village("Singa", "66010")
    p.village("Saru", "66009")
    p.village("Sakurgi", "66008")
    p.village("Tiitsa", "66011")
    p.village("Tursa", "66012")
    p.village("Tundu", "66016")
    p.village("Kuutsi", "66018")
    p.village("Hüti", "66014")
    p.village("Villike", "66017")
    p.village("Vastse-Roosa", "66013")

    p.municipality("Haanja", "")
    p.village("Pausakunnu", "65131")
    p.village("Andsumäe", "")
    p.village("Mustahamba", "")
    p.village("Mäe-Suhka", "65128")
    p.village("Mäe-Tilga", "65129")
    p.village("Tsiamäe", "65144")
    p.village("Soodi", "65142")
    p.village("Trolla", "65143")
    p.village("Purka", "65137")
    p.village("Posti", "65183")
    p.village("Kirbu", "65118")
    p.village("Vaarkali", "")
    p.village("Kääraku", "65120")
    p.village("Tsiiruli", "65196")
    p.village("Haavistu", "65105")
    p.village("Tsilgutaja", "65198")
    p.village("Lillimõisa", "65169")
    p.village("Saluora", "65190")
    p.village("Märdimiku", "65177")
    p.village("Rusa", "65189")
    p.village("Vastsekivi", "65191")
    p.village("Käänu", "65167")
    p.village("Holdi", "")
    p.village("Vaalimäe", "65148")
    p.village("Tõnkova", "65166")
    p.village("Mäe-Palo", "65176")
    p.village("Pressi", "65136")
    p.village("Kergatsi", "65117")
    p.village("Kuiandi", "65162")
    p.village("Ihatsi", "65109")
    p.village("Kaldemäe", "65114")
    p.village("Raagi", "65188")
    p.village("Horoski", "65107")
    p.village("Pillardi", "65182")
    p.village("Külma", "65121")
    p.village("Kaaratautsa", "65113")
    p.village("Sarise", "65192")
    p.village("Saika", "")
    p.village("Hulaku", "65156")
    p.village("Palanumäe", "65130")
    p.village("Preeksa", "65184")
    p.village("Naapka", "65178")
    p.village("Kriguli", "65161")
    p.village("Ala-Suhka", "65103")
    p.village("Sormuli", "65194")
    p.village("Vihkla", "65193")
    p.village("Kuklase", "65163")
    p.village("Palli", "65179")
    p.village("Ruusmäe", "65102")
    p.village("Loogamäe", "65170")
    p.village("Meelaku", "65125")
    p.village("Murati", "65174")
    p.village("Uue-Saaluse", "65147")
    p.village("Lüütsepä", "65172")
    p.village("Ala-Palo", "65152")
    p.village("Mallika", "65124")
    p.village("Mahtja", "65123")
    p.village("Kaloga", "65116")
    p.village("Vungi", "65181")
    p.village("Ala-Tilga", "65104")
    p.village("Resto", "65138")
    p.village("Leoski", "65122")
    p.village("Palujüri", "65180")
    p.village("Tummelka", "65146")
    p.village("Vänni", "65151")
    p.village("Hanija", "65155")
    p.village("Plaksi", "65135")
    p.village("Kilomani", "65159")
    p.village("Piipsemäe", "65133")
    p.village("Luutsniku", "65110")
    p.village("Puspuri", "65186")
    p.village("Hämkoti", "65108")
    p.village("Simula", "65141")
    p.village("Vorstimäe", "65197")
    p.village("Miilimäe", "65126")
    p.village("Kuura", "65164")
    p.village("Kõomäe", "65119")
    p.village("Söödi", "65195")
    p.village("Plaani", "65134")
    p.village("Vakari", "65149")
    p.village("Peedo", "65132")
    p.village("Tuuka", "65199")
    p.village("Pundi", "65185")
    p.village("Kotka", "65160")

    p.municipality("Urvaste", "")
    p.village("Kuldre", "")
    p.village("Lümatu", "66515")
    p.village("Uhtjärve", "66508")
    p.village("Visela", "66510")
    p.village("Kirikuküla", "66512")
    p.village("Pihleni", "66506")
    p.village("Vaabina", "66519")
    p.village("Uue-Antsla", "66509")
    p.village("Koigu", "66513")
    p.village("Kassi", "66504")
    p.village("Kõlbi", "66505")
    p.village("Toku", "66507")
    p.village("Ruhingu", "66516")

    p.municipality("Lasva", "")
    p.village("Nõnova", "65230")
    p.village("Lauga", "65506")
    p.village("Listaku", "")
    p.village("Kõrgessaare", "65404")
    p.village("Kaku", "")
    p.village("Kääpa", "65545")
    p.village("Puusepa", "65551")
    p.village("Mõrgi", "65549")
    p.village("Peraküla", "65510")
    p.village("Noodasküla", "65229")
    p.village("Kannu", "65544")
    p.village("Saaremaa", "65240")
    p.village("Kühmamäe", "65405")
    p.village("Madala", "65406")
    p.village("Tohkri", "65249")
    p.village("Oleski", "65507")
    p.village("Mäessaare", "65407")
    p.village("Tammsaare", "65413")
    p.village("Rusima", "65412")
    p.village("Lehemetsa", "65546")
    p.village("Sooküla", "65244")
    p.village("Voki-Tamme", "65415")
    p.village("Tüütsmäe", "65251")
    p.village("Pindi", "65410")
    p.village("Tiri", "65414")
    p.village("Villa", "")
    p.village("Pässä", "65411")
    p.village("Hellekunnu", "65402")
    p.village("Otsa", "65408")
    p.village("Pikasilla", "65511")
    p.village("Pikakannu", "65409")
    p.village("Pille", "65512")
    p.village("Tsolgo", "65552")
    p.village("Husari", "65403")
    p.village("Paidra", "65508")

    p.municipality("Misso", "")
    p.village("Häärmäni", "65209")
    p.village("Põnni", "65042")
    p.village("Mokra", "65020")
    p.village("Kärinä", "65041")
    p.village("Sapi", "65242")
    p.village("Pupli", "65026")
    p.village("Tserebi", "65039")
    p.village("Tiastõ", "65036")
    p.village("Tiilige", "65037")
    p.village("Ritsiko", "65029")
    p.village("Kriiva", "65013")
    p.village("Põrstõ", "65027")
    p.village("Suurõsuu", "65035")
    p.village("Lütä", "65018")
    p.village("Tika", "65248")
    p.village("Määsi", "65045")
    p.village("Kaubi", "65006")
    p.village("Parmu", "65023")
    p.village("Hürsi", "65158")
    p.village("Savimäe", "65033")
    p.village("Savioja", "")
    p.village("Korgõssaarõ", "65010")
    p.village("Mauri", "65225")
    p.village("Horosuu", "65005")
    p.village("Pruntova", "65024")
    p.village("Tsiistre", "65002")
    p.village("Laisi", "65016")
    p.village("Kurõ", "65014")
    p.village("Hino", "65004")
    p.village("Pältre", "65236")
    p.village("Koorla", "65009")
    p.village("Muraski", "65021")
    p.village("Siksälä", "65034")
    p.village("Napi", "65022")
    p.village("Kossa", "65012")
    p.village("Kiviora", "65008")
    p.village("Väiko-Tiilige", "65040")
    p.village("Käbli", "65015")
    p.village("Saagri", "")
    p.village("Möldre", "65228")
    p.village("Kundsa", "65220")
    p.village("Hindsa", "65003")
    p.village("Kimalasõ", "65007")
    p.village("Rammuka", "65028")
    p.village("Saagrimäe", "65031")
    p.village("Sakudi", "65032")
    p.village("Pedejä", "65233")
    p.village("Leimani", "65017")
    p.village("Missokülä", "65019")
    p.village("Sandi", "65043")

    p.municipality("Meremäe", "")
    p.village("Obinitsa", "")
    p.village("Kõõru", "65371")
    p.village("Vinski", "65352")
    p.village("Vaaksaarõ", "65350")
    p.village("Ruutsi", "65333")
    p.village("Teterüvä", "65339")
    p.village("Tuulova", "65347")
    p.village("Martsina", "65375")
    p.village("Võmmorski", "65391")
    p.village("Viro", "65353")
    p.village("Antkruva", "65357")
    p.village("Lutja", "65316")
    p.village("Ostrova", "65322")
    p.village("Raotu", "65332")
    p.village("Tessova", "65385")
    p.village("Härmä", "65361")
    p.village("Veretinä", "65390")
    p.village("Lindsi", "65373")
    p.village("Karamsina", "65365")
    p.village("Lepä", "65315")
    p.village("Paklova", "65323")
    p.village("Kiiova", "65366")
    p.village("Miku", "65378")
    p.village("Jaanimäe", "")
    p.village("Väiko-Härmä", "65354")
    p.village("Treiali", "65343")
    p.village("Triginä", "65344")
    p.village("Kuksina", "65314")
    p.village("Pelsi", "65327")
    p.village("Kasakova", "65308")
    p.village("Tsumba", "65386")
    p.village("Tedre", "65384")
    p.village("Marinova", "65317")
    p.village("Rokina", "65381")
    p.village("Kiislova", "65311")
    p.village("Kuigõ", "65313")
    p.village("Tsergondõ", "65345")
    p.village("Tääglova", "65388")
    p.village("Korski", "65369")
    p.village("Palandõ", "65324")
    p.village("Juusa", "65364")
    p.village("Miikse", "65319")
    p.village("Serga", "65334")
    p.village("Tsirgu", "65346")
    p.village("Navikõ", "65379")
    p.village("Küllätüvä", "65372")
    p.village("Ala-Tsumba", "65356")
    p.village("Ermakova", "65358")
    p.village("Maaslova", "65374")
    p.village("Kusnetsova", "65370")
    p.village("Kiksova", "65367")
    p.village("Ulaskova", "65348")
    p.village("Sirgova", "65335")
    p.village("Sulbi", "")
    p.village("Paloveere", "")
    p.village("Tiirhanna", "65340")
    p.village("Tuplova", "65387")
    p.village("Tobrova", "65342")
    p.village("Väiko-Serga", "65355")
    p.village("Talka", "65383")
    p.village("Jõksi", "65305")
    p.village("Hilläkeste", "65303")
    p.village("Tiklasõ", "65341")
    p.village("Masluva", "65376")
    p.village("Pliia", "65329")
    p.village("Kalatsova", "65306")
    p.village("Klistina", "65368")
    p.village("Vasla", "65389")
    p.village("Helbi", "65359")
    p.village("Hilana", "65360")
    p.village("Melso", "65377")
    p.village("Kangavitsa", "65307")
    p.village("Keerba", "65310")
    p.village("Merekülä", "65318")
    p.village("Puista", "65331")
    p.village("Kitsõ", "65312")
    p.village("Olehkova", "65321")
    p.village("Palo", "65325")
    p.village("Ignasõ", "65362")
    p.village("Poksa", "65330")
    p.village("Seretsüvä", "65382")
    p.village("Tepia", "65338")
    p.village("Kastamara", "65309")
    p.village("Polovina", "65380")
    p.village("Uusvada", "65349")

    p.municipality("Kirumpää", "")
    p.municipality("Navi", "")
    p.municipality("Meegomäe", "")
    



# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Rapla (county)
    p.county("Rapla", "")
    p.municipality("Kehtna", "")
    p.smallborough("Lelle", "")
    p.smallborough("Eidapere", "")
    p.smallborough("Kaerepere", "")
    p.village("Saksa", "")
    p.village("Ohekatku", "")
    p.village("Rõue", "")
    p.smallborough("Keava", "")
    p.village("Käbiküla", "")
    p.village("Metsaääre", "")
    p.village("Kehtna-Nurme", "79051")
    p.village("Laeste", "79064")
    p.village("Koogimäe", "79052")
    p.village("Palasi", "79018")
    p.village("Kärpla", "79063")
    p.village("Kastna", "79016")
    p.village("Vastja", "79071")
    p.village("Lau", "79008")
    p.village("Linnaaluste", "79050")
    p.village("Reonda", "79015")
    p.village("Kõrbja", "79023")
    p.village("Selja", "79110")
    p.village("Ellamaa", "79011")
    p.village("Sooaluste", "79070")
    p.village("Ahekõnnu", "79111")
    p.village("Kalbu", "79061")
    p.village("Mukri", "79013")
    p.village("Saarepõllu", "79014")
    p.village("Lokuta", "")
    p.village("Põrsaku", "79524")
    p.village("Hertu", "79521")
    p.village("Pae", "79009")
    p.village("Nadalama", "79068")
    p.village("Lellapere-Nurme", "79066")
    p.village("Lalli", "79017")
    p.village("Nõlva", "79112")
    p.village("Hiie", "79060")
    p.village("Kenni", "79012")
    p.village("Haakla", "79021")
    p.village("Paluküla", "79019")
    p.village("Saunaküla", "79526")
    p.village("Koogiste", "79022")
    p.village("Lellapere", "79065")
    p.village("Valtu-Nurme", "79527")
    p.village("Kumma", "79523")
    p.village("Ingliste", "79004")
    p.village("Põllu", "79020")

    p.town("Rapla", "")
    p.village("Uusküla", "")
    p.smallborough("Hagudi", "")
    p.smallborough("Alu", "")
    p.village("Sulupere", "")
    p.village("Mahlamäe", "")
    p.village("Tuti", "")
    p.smallborough("Kuusiku", "")
    p.village("Kalevi", "")
    p.village("Kuku", "")
    p.village("Purila", "")
    p.village("Valtu", "")
    p.village("Kodila", "")
    p.village("Sikeldi", "")
    p.village("Ülejõe", "")
    p.village("Oola", "79643")
    p.village("Kõrgu", "79615")
    p.village("Alu-Metsküla", "79605")
    p.village("Seli", "79604")
    p.village("Tõrma", "79622")
    p.village("Seli-Nurme", "79634")
    p.village("Röa", "79614")
    p.village("Aranküla", "79640")
    p.village("Oela", "79617")
    p.village("Ohulepa", "79618")
    p.village("Kodila-Metsküla", "79613")
    p.village("Äherdi", "79644")
    p.village("Juula", "79540")
    p.village("Mõisaaseme", "79632")
    p.village("Tapupere", "79621")
    p.village("Ridaküla", "79528")
    p.village("Palamulla", "79619")
    p.village("Väljataguse", "79543")
    p.village("Lipstu", "79519")
    p.village("Kelba", "79611")
    p.village("Koigi", "79630")
    p.village("Kuusiku-Nõmme", "79518")
    p.village("Mällu", "79616")
    p.village("Nõmme", "79642")
    p.village("Raka", "79620")
    p.village("Iira", "79517")

    p.municipality("Märjamaa", "")
    p.village("Sõtke", "")
    p.village("Maidla", "")
    p.village("Sipa", "")
    p.village("Moka", "78236")
    p.village("Kasti", "78221")
    p.village("Vana-Nurtu", "78258")
    p.village("Kangru", "78220")
    p.village("Sõmeru", "78255")
    p.village("Purga", "78249")
    p.village("Velise-Nõlva", "78260")
    p.village("Laukna", "")
    p.village("Napanurga", "78240")
    p.village("Inda", "78216")
    p.village("Pajaka", "78248")
    p.village("Risu-Suurküla", "78252")
    p.village("Veski", "78261")
    p.village("Urevere", "78120")
    p.village("Mõraste", "78116")
    p.village("Loodna", "78113")
    p.village("Kiilaspere", "78223")
    p.village("Paisumaa", "78247")
    p.village("Aravere", "78213")
    p.village("Valgu", "78204")
    p.village("Vanamõisa", "")
    p.village("Konuvere", "78227")
    p.village("Altküla", "78212")
    p.village("Nõmmeotsa", "78242")
    p.village("Rassiotsa", "78251")
    p.village("Varbola", "78203")
    p.village("Nurme", "78241")
    p.village("Ohukotsu", "78244")
    p.village("Mäliste", "78238")
    p.village("Kohtru", "78226")
    p.village("Russalu", "78317")
    p.village("Leevre", "78112")
    p.village("Keskküla", "78222")
    p.village("Kaguvere", "78219")
    p.village("Alaküla", "78211")
    p.village("Metsküla", "")
    p.village("Velise", "78201")
    p.village("Orgita", "78313")
    p.village("Naistevalla", "78239")
    p.village("Paaduotsa", "78246")
    p.village("Nurtu-Nõlva", "78207")
    p.village("Velisemõisa", "78259")
    p.village("Kilgi", "78224")
    p.village("Paeküla", "78206")
    p.village("Sulu", "78253")
    p.village("Vaimõisa", "78205")
    p.village("Kunsu", "78228")
    p.village("Kirna", "78225")
    p.village("Aruküla", "78214")
    p.village("Vilta", "78121")
    p.village("Võeva", "78262")
    p.village("Lestima", "78232")
    p.village("Käriselja", "78231")
    p.village("Päädeva", "78314")
    p.village("Ojaäärse", "78245")
    p.village("Teenuse", "78103")
    p.village("Nääri", "78243")
    p.village("Põlli", "78250")
    p.village("Sooniste", "78118")
    p.village("Kohatu", "78111")
    p.village("Jõeääre", "78218")
    p.village("Haimre", "78202")
    p.village("Luiste", "78114")
    p.village("Männiku", "78117")
    p.village("Suurküla", "78254")
    p.village("Soosalu", "78119")
    p.village("Rangu", "78315")
    p.village("Ringuta", "78316")
    p.village("Koluta", "78311")
    p.village("Hiietse", "78215")
    p.village("Kõrtsuotsa", "78229")
    p.village("Jaaniveski", "78217")
    p.village("Tolli", "78256")
    p.village("Mõisamaa", "78237")

    p.municipality("Järvakandi", "")
    p.municipality("Juuru", "")
    p.smallborough("Juuru", "")
    p.village("Järlepa", "")
    p.village("Pirgu", "")
    p.village("Orguse", "")
    p.village("Hõreda", "79010")
    p.village("Härgla", "79404")
    p.village("Atla", "79403")
    p.village("Mahtra", "79407")
    p.village("Vankse", "79406")
    p.village("Helda", "79417")
    p.village("Kalda", "79418")
    p.village("Sadala", "79419")
    p.village("Jaluse", "79410")
    p.village("Lõiuse", "79405")

    p.municipality("Kaiu", "")
    p.village("Kuimetsa", "")
    p.village("Oblu", "79312")
    p.village("Karitsa", "79320")
    p.village("Kasvandu", "79321")
    p.village("Tolla", "79322")
    p.village("Põlliku", "79325")
    p.village("Vahastu", "79303")
    p.village("Tamsi", "79313")
    p.village("Vaopere", "79314")
    p.village("Suurekivi", "79333")
    p.village("Toomja", "79323")
    p.village("Vana-Kaiu", "79324")

    p.municipality("Käru", "")
    p.village("Sonni", "")
    p.village("Lauri", "79215")
    p.village("Kõdu", "79212")
    p.village("Kädva", "79213")
    p.village("Lungu", "79216")
    p.village("Kändliku", "79214")
    p.village("Kullimaa", "79211")
    p.village("Jõeküla", "79218")

    p.municipality("Kohila", "")
    p.smallborough("Prillimäe", "")
    p.village("Lohu", "")
    p.village("Urge", "")
    p.smallborough("Hageri", "")
    p.village("Salutaguse", "")
    p.village("Vilivere", "")
    p.village("Sutlema", "")
    p.smallborough("Aespa", "")
    p.village("Masti", "")
    p.village("Pukamäe", "")
    p.village("Angerja", "79741")
    p.village("Lümandu", "")
    p.village("Pihali", "79703")
    p.village("Adila", "79704")
    p.village("Loone", "79831")
    p.village("Põikma", "79709")
    p.village("Rootsi", "79815")
    p.village("Kadaka", "79811")
    p.village("Rabivere", "79610")
    p.village("Aandu", "79810")
    p.village("Mälivere", "79814")
    p.village("Pahkla", "79742")
    p.village("Vana-Aespa", "79748")

    p.municipality("Vigala", "")
    p.village("Vana-Vigala", "78003")
    p.village("Kivi-Vigala", "78001")
    p.village("Kojastu", "78016")
    p.village("Palase", "78025")
    p.village("Tiduvere", "78031")
    p.village("Paljasmaa", "78026")
    p.village("Rääski", "78029")
    p.village("Naravere", "78022")
    p.village("Oese", "78023")
    p.village("Araste", "78011")
    p.village("Kurevere", "78018")
    p.village("Manni", "78021")
    p.village("Vaguja", "78032")
    p.village("Tõnumaa", "78004")
    p.village("Ojapere", "78024")
    p.village("Kausi", "78014")
    p.village("Vängla", "78034")
    p.village("Kesu", "78015")
    p.village("Pallika", "78027")
    p.village("Jädivere", "78013")
    p.village("Sääla", "78030")
    p.village("Läti", "78020")
    p.village("Leibre", "78019")
    p.village("Konnapere", "78017")
    p.village("Päärdu", "78028")
    p.village("Avaste", "78012")

    p.municipality("Raikküla", "")
    p.village("Tamme", "")
    p.village("Loe", "")
    p.village("Nõmmküla", "78408")
    p.village("Jalase", "78415")
    p.village("Purku", "78401")
    p.village("Pühatu", "78421")
    p.village("Keo", "78404")
    p.village("Vahakõnnu", "78411")
    p.village("Põlma", "78410")
    p.village("Lipa", "78405")
    p.village("Lipametsa", "78406")
    p.village("Raela", "78409")
    p.village("Kõrvetaguse", "78417")
    p.village("Riidaku", "78422")
    p.village("Koikse", "78416")
    p.village("Valli", "78413")
    p.village("Nõmmemetsa", "78420")
    p.village("Kaigepere", "78412")
    p.village("Ummaru", "78423")
    p.village("Lõpemetsa", "78419")





# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Lääne-Viru (county)
    p.county("Lääne-Viru", "")
    p.municipality("Tapa", "")
    p.smallborough("Lehtse", "")
    p.village("Kuru", "")
    p.village("Jäneda", "")
    p.village("Imastu", "45001")
    p.village("Nõmmküla", "")
    p.village("Karkuse", "")
    p.village("Näo", "45007")
    p.village("Linnape", "73606")
    p.village("Läpi", "73607")
    p.village("Läste", "73608")
    p.village("Vahakulmu", "45011")
    p.village("Raudla", "73612")
    p.village("Rabasaare", "73611")
    p.village("Kõrveküla", "")
    p.village("Räsna", "73614")
    p.village("Lokuta", "45004")
    p.village("Patika", "73609")
    p.village("Tõõrakõrve", "73615")
    p.village("Pruuna", "73610")
    p.village("Jootme", "73603")
    p.village("Saiakopli", "45009")
    p.village("Piilu", "45008")
    p.village("Saksi", "45010")
    p.village("Loksu", "45003")
    p.village("Moe", "45005")

    p.municipality("Rakvere", "")
    p.smallborough("Lepna", "")
    p.village("Päide", "")
    p.village("Tõrremäe", "")
    p.village("Veltsi", "")
    p.village("Lasila", "")
    p.village("Taaravainu", "")
    p.village("Kõrgemäe", "")
    p.village("Arkna", "")
    p.village("Tõrma", "44406")
    p.village("Eesküla", "44405")
    p.village("Paatna", "44411")
    p.village("Mädapea", "44409")
    p.village("Karunga", "44404")
    p.village("Levala", "")
    p.village("Kullaaru", "44410")
    p.village("Tobia", "44416")
    p.village("Kloodi", "44413")
    p.village("Järni", "44407")
    p.village("Karivärava", "44412")
    p.village("Karitsa", "44403")

    p.municipality("Vinni", "")
    p.smallborough("Tudu", "")
    p.village("Piira", "")
    p.village("Mõdriku", "")
    p.smallborough("Roela", "")
    p.village("Lähtse", "")
    p.village("Vetiku", "")
    p.village("Kakumäe", "")
    p.village("Küti", "")
    p.smallborough("Pajusti", "")
    p.village("Kadila", "")
    p.smallborough("Viru-Jaagupi", "")
    p.village("Veadla", "")
    p.village("Allika", "46612")
    p.village("Obja", "46629")
    p.village("Anguse", "46615")
    p.village("Kannastiku", "46622")
    p.village("Suigu", "46637")
    p.village("Lepiku", "46627")
    p.village("Koeravere", "46613")
    p.village("Rünga", "46634")
    p.village("Rasivere", "46632")
    p.village("Aravuse", "46616")
    p.village("Kaukvere", "46623")
    p.village("Soonuka", "46636")
    p.village("Palasi", "46630")
    p.village("Nurmetu", "46628")
    p.village("Võhu", "46620")
    p.village("Mäetaguse", "46639")
    p.village("Ristiküla", "46633")
    p.village("Voore", "46642")
    p.village("Puka", "46631")
    p.village("Kulina", "46625")
    p.village("Aruküla", "46617")
    p.village("Alavere", "46611")
    p.village("Inju", "46619")
    p.village("Vana-Vinni", "46640")
    p.village("Saara", "46635")
    p.village("Kehala", "46624")
    p.village("Aruvälja", "46618")

    p.town("Tamsalu", "")
    p.smallborough("Sääse", "")
    p.village("Vajangu", "")
    p.village("Porkuni", "")
    p.village("Assamalla", "")
    p.village("Sauvälja", "46023")
    p.village("Järsi", "46007")
    p.village("Savalduma", "46024")
    p.village("Järvajõe", "46008")
    p.village("Araski", "46005")
    p.village("Uudeküla", "46026")
    p.village("Koplitaguse", "46013")
    p.village("Naistevälja", "46020")
    p.village("Lemmküla", "46017")
    p.village("Vadiküla", "46027")
    p.village("Kerguta", "46011")
    p.village("Vistla", "46028")
    p.village("Kuie", "46014")
    p.village("Kaeva", "46010")
    p.village("Loksa", "46018")
    p.village("Alupere", "46004")
    p.village("Võhmetu", "46029")
    p.village("Kursi", "46016")
    p.village("Võhmuta", "46030")
    p.village("Koiduküla", "46012")
    p.village("Kullenga", "46015")
    p.village("Metskaevu", "46019")
    p.village("Põdrangu", "46022")
    p.village("Piisupi", "46021")
    p.village("Türje", "46025")

    p.municipality("Rakke", "")
    p.village("Suure-Rakke", "")
    p.village("Mõisamaa", "")
    p.village("Edru", "46304")
    p.village("Mäiste", "46320")
    p.village("Kõpsta", "46314")
    p.village("Padaküla", "46323")
    p.village("Tammiku", "")
    p.village("Ao", "46303")
    p.village("Kadiküla", "46308")
    p.village("Väike-Rakke", "46331")
    p.village("Väike-Tammiku", "46332")
    p.village("Emumäe", "46305")
    p.village("Sootaguse", "")
    p.village("Piibe", "46324")
    p.village("Liigvalla", "46318")
    p.village("Olju", "46322")
    p.village("Kellamäe", "46310")
    p.village("Kamariku", "46309")
    p.village("Koluvere", "46313")
    p.village("Kitsemetsa", "46311")
    p.village("Kaavere", "46307")
    p.village("Lahu", "46315")
    p.village("Salla", "46302")
    p.village("Villakvere", "46330")
    p.village("Koila", "")
    p.village("Räitsvere", "46325")
    p.village("Lasinurme", "46317")
    p.village("Lammasküla", "46316")

    p.municipality("Väike-Maarja", "")
    p.smallborough("Simuna", "")
    p.smallborough("Kiltsi", "")
    p.village("Triigi", "")
    p.village("Vao", "")
    p.village("Ebavere", "")
    p.village("Nadalama", "46221")
    p.village("Raigu", "46227")
    p.village("Aburi", "46206")
    p.village("Eipri", "46210")
    p.village("Pikevere", "46204")
    p.village("Käru", "46217")
    p.village("Orguse", "46223")
    p.village("Imukvere", "46212")
    p.village("Koonu", "46213")
    p.village("Pudivere", "46225")
    p.village("Avanduse", "46207")
    p.village("Pandivere", "46224")
    p.village("Rastla", "46228")
    p.village("Varangu", "")
    p.village("Uuemõisa", "46229")
    p.village("Kännuküla", "46215")
    p.village("Raeküla", "46226")
    p.village("Vorsti", "46232")
    p.village("Äntu", "46234")
    p.village("Ärina", "46235")
    p.village("Määri", "46219")
    p.village("Nõmme", "46222")
    p.village("Kurtna", "46214")
    p.village("Aavere", "")
    p.village("Liivaküla", "46218")
    p.village("Võivere", "46233")
    p.village("Avispea", "46208")
    p.village("Hirla", "46211")
    p.village("Kärsa", "46216")
    p.village("Müüriku", "46220")

    p.municipality("Sõmeru", "")
    p.smallborough("Uhtna", "")
    p.village("Ubja", "")
    p.village("Toomla", "")
    p.village("Ussimäe", "")
    p.smallborough("Näpi", "")
    p.village("Roodevälja", "")
    p.village("Vaeküla", "")
    p.village("Kohala", "")
    p.village("Rägavere", "")
    p.village("Põlula", "")
    p.village("Nõmmise", "46710")
    p.village("Viru-Kabala", "46714")
    p.village("Miila", "46706")
    p.village("Sae", "46712")
    p.village("Kantküla", "46703")
    p.village("Kõrma", "46704")
    p.village("Nurkse", "46709")
    p.village("Lavi", "46705")
    p.village("Mõedaka", "46708")
    p.village("Ulvi", "46701")
    p.village("Aasuvälja", "46702")
    p.village("Uljaste", "46713")
    p.village("Männikvälja", "46707")

    p.village("Katku", "44214")
    p.village("Sämi-Tagaküla", "44225")
    p.village("Sooaluse", "44223")
    p.village("Jäätma", "")
    p.village("Kohala-Eesküla", "44216")
    p.village("Koovälja", "44217")
    p.village("Katela", "44213")
    p.village("Raudlepa", "44221")
    p.village("Sämi", "44224")
    p.village("Aluvere", "44208")
    p.village("Aresi", "44210")
    p.village("Kaarli", "44212")
    p.village("Nurme", "44219")
    p.village("Rahkla", "")
    p.village("Raudvere", "44222")
    p.village("Varudi-Altküla", "44228")
    p.village("Varudi-Vanaküla", "44229")
    p.village("Muru", "44218")
    p.village("Andja", "44209")
    p.village("Papiaru", "44206")

    p.municipality("Vihula", "")
    p.smallborough("Võsu", "")
    p.village("Käsmu", "")
    p.village("Sagadi", "")
    p.village("Võsupere", "")
    p.village("Palmse", "")
    p.village("Oandu", "")
    p.village("Metsiku", "45427")
    p.village("Annikvere", "45410")
    p.village("Ilumäe", "45414")
    p.village("Adaka", "45407")
    p.village("Kakuvälja", "45416")
    p.village("Villandi", "45449")
    p.village("Koolimäe", "45420")
    p.village("Natturi", "45430")
    p.village("Lahe", "45423")
    p.village("Joandu", "45415")
    p.village("Vila", "45448")
    p.village("Rutja", "45451")
    p.village("Metsanurga", "45426")
    p.village("Lauli", "45424")
    p.village("Altja", "45408")
    p.village("Pajuveski", "45434")
    p.village("Võhma", "")
    p.village("Karula", "45417")
    p.village("Noonu", "45431")
    p.village("Korjuse", "45421")
    p.village("Haili", "45413")
    p.village("Tepelvälja", "45440")
    p.village("Mustoja", "45429")
    p.village("Tõugu", "45444")
    p.village("Muike", "45428")
    p.village("Tidriku", "45441")
    p.village("Toolse", "45443")
    p.village("Eru", "45412")
    p.village("Pihlaspea", "45437")
    p.village("Salatse", "45439")
    p.village("Paasi", "45433")
    p.village("Tiigi", "45442")
    p.village("Lobi", "45425")
    p.village("Karepa", "45401")
    p.village("Aasumetsa", "45406")
    p.village("Andi", "45409")
    p.village("Kosta", "45422")
    p.village("Vainupea", "45446")
    p.village("Pedassaare", "45436")
    p.village("Koljaku", "45419")
    p.village("Vatku", "45447")
    p.village("Sakussaare", "45438")
    p.village("Uusküla", "45445")
    p.village("Kiva", "45418")
    p.village("Vergi", "45404")

    p.municipality("Haljala", "")
    p.village("Essu", "")
    p.village("Aaspere", "")
    p.village("Vanamõisa", "45319")
    p.village("Kandle", "45308")
    p.village("Pehka", "45315")
    p.village("Kärmu", "45311")
    p.village("Põdruse", "45316")
    p.village("Tatruse", "45318")
    p.village("Auküla", "45306")
    p.village("Kõldu", "45312")
    p.village("Kisuvere", "45310")
    p.village("Kavastu", "45309")
    p.village("Aasu", "45304")
    p.village("Lihulõpe", "45313")
    p.village("Võle", "45321")
    p.village("Idavere", "45307")
    p.village("Aaviku", "45305")
    p.village("Sauste", "45317")
    p.village("Liiguste", "45314")

    p.town("Kunda", "")
    p.municipality("Kadrina", "")
    p.village("Viitna", "")
    p.smallborough("Hulja", "")
    p.village("Tokolopi", "")
    p.village("Kadapiku", "")
    p.village("Tirbiku", "")
    p.village("Mõndavere", "45222")
    p.village("Võduvere", "45238")
    p.village("Kihlevere", "45215")
    p.village("Mäo", "45223")
    p.village("Põima", "45228")
    p.village("Vandu", "45237")
    p.village("Uku", "45234")
    p.village("Läsna", "45221")
    p.village("Vohnja", "45204")
    p.village("Ohepalu", "45225")
    p.village("Arbavere", "45206")
    p.village("Kiku", "45216")
    p.village("Vaiatu", "45236")
    p.village("Ama", "45205")
    p.village("Loobu", "45220")
    p.village("Udriku", "45233")
    p.village("Hõbeda", "45207")
    p.village("Rõmeda", "45230")
    p.village("Kallukse", "45214")
    p.village("Jõepere", "45209")
    p.village("Undla", "45235")
    p.village("Neeruti", "45224")
    p.village("Ridaküla", "45229")
    p.village("Lante", "45218")
    p.village("Võipere", "45239")
    p.village("Leikude", "45219")
    p.village("Härjadi", "45208")
    p.village("Orutaguse", "45226")
    p.village("Jõetaguse", "45210")
    p.village("Salda", "45231")
    p.village("Saukse", "45232")
    p.village("Pariisi", "45227")

    p.municipality("Laekvere", "")
    p.village("Muuga", "")
    p.village("Vassivere", "46519")
    p.village("Alekvere", "46505")
    p.village("Rajaküla", "46513")
    p.village("Kellavere", "46508")
    p.village("Salutaguse", "46516")
    p.village("Venevere", "46504")
    p.village("Rohu", "46515")
    p.village("Moora", "46510")
    p.village("Arukse", "46514")
    p.village("Kaasiksaare", "46507")
    p.village("Sirevere", "46517")
    p.village("Ilistvere", "46506")
    p.village("Padu", "46512")
    p.village("Luusika", "46509")
    p.village("Paasvere", "46511")

    p.municipality("Viru-Nigula", "")
    p.village("Siberi", "44028")
    p.village("Selja", "44027")
    p.village("Vasta", "44034")
    p.village("Kabeli", "44004")
    p.village("Kuura", "44012")
    p.village("Malla", "44016")
    p.village("Võrkla", "44035")
    p.village("Kaliküla", "44005")
    p.village("Samma", "44026")
    p.village("Ojaküla", "44020")
    p.village("Letipea", "44013")
    p.village("Nugeri", "44019")
    p.village("Linnuse", "44014")
    p.village("Pikaristi", "44024")
    p.village("Iila", "44003")
    p.village("Tüükri", "44031")
    p.village("Toomika", "44030")
    p.village("Kutsala", "44011")
    p.village("Kurna", "44010")
    p.village("Aasukalda", "44002")
    p.village("Mahu", "44015")
    p.village("Paasküla", "44021")
    p.village("Varudi", "44033")
    p.village("Pärna", "44025")
    p.village("Simunamäe", "44029")
    p.village("Pada", "44023")
    p.village("Pada-Aruküla", "44022")
    p.village("Villavere", "44037")
    p.village("Kanguristi", "44006")
    p.village("Marinu", "44017")
    p.village("Metsavälja", "44018")
    p.village("Kiviküla", "44007")
    p.village("Unukse", "44032")

    p.municipality("Eisma", "")




# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Saare (county)
    p.county("Saare", "")
    p.municipality("Leisi", "")
    p.village("Parasmetsa", "94241")
    p.village("Hiievälja", "94231")
    p.village("Triigi", "94243")
    p.village("Lõpi", "94255")
    p.village("Luulupe", "94251")
    p.village("Metsküla", "94271")
    p.village("Asuka", "94257")
    p.village("Paaste", "94240")
    p.village("Moosi", "94236")
    p.village("Jõiste", "94232")
    p.village("Angla", "94244")
    p.village("Purtsa", "94264")
    p.village("Mätja", "94214")
    p.village("Laugu", "94233")
    p.village("Kopli", "94249")
    p.village("Tareste", "94216")
    p.village("Linnaka", "94213")
    p.village("Tõre", "94217")
    p.village("Pöitse", "94259")
    p.village("Poka", "94258")
    p.village("Tiitsuotsa", "94265")
    p.village("Veske", "94247")
    p.village("Nihatu", "94215")
    p.village("Ratla", "94223")
    p.village("Nurme", "")
    p.village("Õeste", "94219")
    p.village("Külma", "94211")
    p.village("Nava", "94252")
    p.village("Metsaääre", "94222")
    p.village("Roobaka", "94242")
    p.village("Mujaste", "94237")
    p.village("Räägi", "94225")
    p.village("Aru", "94245")
    p.village("Koiduvälja", "94261")
    p.village("Oitme", "94239")
    p.village("Murika", "94272")
    p.village("Selja", "94256")
    p.village("Koikla", "94221")
    p.village("Meiuste", "94235")
    p.village("Pammana", "94273")
    p.village("Täätsi", "94224")
    p.village("Aruste", "94212")
    p.village("Tutku", "94250")
    p.village("Peederga", "94246")
    p.village("Soela", "94274")
    p.village("Pärsama", "94201")
    p.village("Pamma", "94263")
    p.village("Karja", "94248")
    p.village("Kaisa", "94254")

    p.municipality("Salme", "")
    p.village("Rahuste", "93235")
    p.village("Lõu", "93234")
    p.village("Kaimri", "93232")
    p.village("Anseküla", "93211")
    p.village("Üüdibe", "93224")
    p.village("Imara", "93213")
    p.village("Metsalõuka", "93218")
    p.village("Hindu", "")
    p.village("Järve", "93271")
    p.village("Tiirimetsa", "93223")
    p.village("Länga", "93215")
    p.village("Tehumardi", "93222")
    p.village("Kaugatoma", "93233")
    p.village("Toomalõuka", "93261")
    p.village("Lahetaguse", "93260")
    p.village("Läätsa", "93216")
    p.village("Möldri", "93220")
    p.village("Lõmala", "93217")
    p.village("Suurna", "93221")
    p.village("Lassi", "93214")
    p.village("Easte", "93212")
    p.village("Vintri", "93237")

    p.municipality("Kaarma", "")
    p.smallborough("Aste", "")
    p.smallborough("Nasva", "")
    p.smallborough("Kudjape", "")
    p.village("Mändjala", "")
    p.village("Muratsi", "")
    p.village("Praakli", "")
    p.village("Laheküla", "")
    p.village("Kirikuküla", "")
    p.village("Sikassaare", "")
    p.village("Upa", "")
    p.village("Vaivere", "")
    p.village("Randvere", "")
    p.village("Abruka", "93826")
    p.village("Kaisvere", "93733")
    p.village("Kiratsi", "93741")
    p.village("Tamsalu", "93840")
    p.village("Hübja", "93715")
    p.village("Õha", "93888")
    p.village("Tõrise", "93886")
    p.village("Parila", "93836")
    p.village("Anijala", "93831")
    p.village("Lilbi", "93853")
    p.village("Kellamäe", "93723")
    p.village("Asuküla", "93717")
    p.village("Ansi", "93832")
    p.village("Kungla", "")
    p.village("Hakjala", "93714")
    p.village("Paimala", "93855")
    p.village("Jootme", "93722")
    p.village("Vantri", "93716")
    p.village("Pähkla", "93874")
    p.village("Eikla", "93881")
    p.village("Tõru", "93887")
    p.village("Tõlli", "93841")
    p.village("Endla", "93712")
    p.village("Meedla", "93744")
    p.village("Vestla", "93746")
    p.village("Koidu", "93834")
    p.village("Mullutu", "93835")
    p.village("Piila", "93885")
    p.village("Viira", "")
    p.village("Aula-Vintri", "93711")
    p.village("Kuke", "93734")
    p.village("Käku", "93753")
    p.village("Koidula", "93884")
    p.village("Pärni", "93837")
    p.village("Irase", "93721")
    p.village("Maleva", "93743")
    p.village("Tahula", "93856")
    p.village("Uduvere", "93745")
    p.village("Kasti", "93858")
    p.village("Laadjala", "93742")
    p.village("Kärdu", "")
    p.village("Nõmme", "")
    p.village("Kaarmise", "93833")
    p.village("Haamse", "93713")
    p.village("Laoküla", "93754")
    p.village("Kaubi", "93882")
    p.village("Unimäe", "93875")
    p.village("Vatsküla", "93891")
    p.village("Keskranna", "93890")
    p.village("Saia", "93725")

    p.municipality("Orissaare", "")
    p.village("Pulli", "94612")
    p.village("Tagavere", "94638")
    p.village("Põripõllu", "94613")
    p.village("Randküla", "94656")
    p.village("Imavere", "94623")
    p.village("Mäeküla", "94632")
    p.village("Järveküla", "94654")
    p.village("Maasi", "94630")
    p.village("Ariste", "")
    p.village("Võhma", "")
    p.village("Taaliku", "94637")
    p.village("Suur-Pahila", "94659")
    p.village("Kalma", "94624")
    p.village("Väljaküla", "")
    p.village("Kõinastu", "94611")
    p.village("Arju", "94622")
    p.village("Kavandi", "94655")
    p.village("Väike-Pahila", "94660")
    p.village("Väike-Rahula", "94640")
    p.village("Kareda", "94625")
    p.village("Saikla", "94634")
    p.village("Raugu", "94658")
    p.village("Tumala", "94639")
    p.village("Mehama", "94631")
    p.village("Orinõmme", "94633")
    p.village("Ööriku", "94642")
    p.village("Salu", "94635")
    p.village("Jaani", "94653")
    p.village("Suur-Rahula", "94636")
    p.village("Haapsu", "94651")
    p.village("Liigalaskma", "94628")
    p.village("Kuninguste", "94626")

    p.municipality("Kärla", "")
    p.village("Sõmera", "")
    p.village("Paiküla", "93562")
    p.village("Kulli", "")
    p.village("Mõnnuste", "93512")
    p.village("Nõmpa", "93846")
    p.village("Vendise", "93848")
    p.village("Kõrkküla", "93527")
    p.village("Hirmuste", "93523")
    p.village("Kogula", "")
    p.village("Ulje", "93529")
    p.village("Käesla", "93526")
    p.village("Kuuse", "93551")
    p.village("Arandi", "93521")
    p.village("Jõempa", "93844")
    p.village("Mätasselja", "93520")
    p.village("Paevere", "93528")
    p.village("Kandla", "93845")
    p.village("Vennati", "93530")
    p.village("Anepesa", "93843")
    p.village("Karida", "93524")
    p.village("Sauvere", "93847")

    p.municipality("Kihelkonna", "")
    p.village("Loona", "")
    p.village("Viki", "")
    p.village("Oju", "")
    p.village("Rootsiküla", "")
    p.village("Karujärve", "")
    p.village("Kuralase", "")
    p.village("Tammese", "93449")
    p.village("Abula", "93461")
    p.village("Virita", "93414")
    p.village("Odalätsi", "93468")
    p.village("Üru", "93471")
    p.village("Kiirassaare", "93433")
    p.village("Läägi", "93456")
    p.village("Kurevere", "93439")
    p.village("Kuusiku", "")
    p.village("Neeme", "93444")
    p.village("Kõõru", "93467")
    p.village("Pidula", "93469")
    p.village("Pajumõisa", "93412")
    p.village("Kõruse", "93440")
    p.village("Tagamõisa", "93448")
    p.village("Vedruka", "93432")
    p.village("Sepise", "93447")
    p.village("Kalmu", "93436")
    p.village("Kuremetsa", "93464")
    p.village("Kuumi", "93465")
    p.village("Vaigu", "93452")
    p.village("Lätiniidi", "93441")
    p.village("Vilsandi", "93421")
    p.village("Undva", "93451")
    p.village("Tohku", "93450")
    p.village("Varkja", "93470")
    p.village("Abaja", "93411")
    p.village("Kehila", "93437")
    p.village("Kotsma", "93434")

    p.town("Kuressaare", "")
    p.municipality("Valjala", "")
    p.village("Põlluküla", "")
    p.village("Oessaare", "94313")
    p.village("Kõriska", "94338")
    p.village("Tõnija", "94344")
    p.village("Vanalõve", "94318")
    p.village("Vilidu", "94347")
    p.village("Jööri", "94332")
    p.village("Võrsna", "94323")
    p.village("Kalju", "94333")
    p.village("Jursi", "94321")
    p.village("Kuiste", "94336")
    p.village("Kalli", "94322")
    p.village("Veeriku", "94346")
    p.village("Männiku", "94340")
    p.village("Kallemäe", "94301")
    p.village("Koksi", "94335")
    p.village("Undimäe", "94345")
    p.village("Röösa", "94343")
    p.village("Siiksaare", "94316")
    p.village("Jõelepa", "94331")
    p.village("Rahu", "94342")
    p.village("Turja", "94317")
    p.village("Väkra", "94348")
    p.village("Lööne", "94339")
    p.village("Sakla", "94315")

    p.municipality("Lümanda", "")
    p.village("Himmiste", "93311")
    p.village("Koki", "93327")
    p.village("Koovi", "93314")
    p.village("Atla", "93322")
    p.village("Kipi", "93313")
    p.village("Vahva", "93319")
    p.village("Viidu", "93343")
    p.village("Leedri", "93316")
    p.village("Kotlandi", "93328")
    p.village("Kuusnõmme", "93342")
    p.village("Karala", "93325")
    p.village("Austla", "93323")
    p.village("Taritu", "93331")
    p.village("Vana-Lahetaguse", "93320")
    p.village("Varpe", "93321")
    p.village("Riksu", "93330")
    p.village("Jõgela", "93312")
    p.village("Eeriksaare", "93324")
    p.village("Metsapere", "93329")
    p.village("Koimla", "93326")

    p.municipality("Pöide", "")
    p.village("Tornimäe", "")
    p.village("Muraja", "")
    p.village("Veere", "")
    p.village("Kanissaare", "94533")
    p.village("Unguma", "94545")
    p.village("Reina", "94553")
    p.village("Kübassaare", "94534")
    p.village("Kakuna", "94532")
    p.village("Sundimetsa", "94521")
    p.village("Kõrkvere", "94535")
    p.village("Mui", "94543")
    p.village("Ula", "")
    p.village("Ardla", "94531")
    p.village("Are", "94511")
    p.village("Metsara", "94551")
    p.village("Oti", "94518")
    p.village("Keskvere", "")
    p.village("Välta", "94540")
    p.village("Neemi", "94537")
    p.village("Koigi", "94515")
    p.village("Talila", "94538")
    p.village("Uuemõisa", "94522")
    p.village("Levala", "94517")
    p.village("Nenu", "94552")
    p.village("Kahutsi", "94513")
    p.village("Kärneri", "94542")
    p.village("Puka", "94519")
    p.village("Iruste", "94512")

    p.municipality("Pihtla", "")
    p.village("Kaali", "")
    p.village("Suure-Rootsi", "")
    p.village("Kõljala", "")
    p.village("Püha", "94117")
    p.village("Reeküla", "94148")
    p.village("Metsaküla", "")
    p.village("Hämmelepa", "94111")
    p.village("Kõnnu", "")
    p.village("Tõlluste", "94124")
    p.village("Nässuma", "94116")
    p.village("Haeska", "94142")
    p.village("Matsiranna", "94154")
    p.village("Reo", "94171")
    p.village("Räimaste", "94120")
    p.village("Sepa", "")
    p.village("Sutu", "94123")
    p.village("Eiste", "94141")
    p.village("Masa", "94146")
    p.village("Kiritu", "94113")
    p.village("Ennu", "94126")
    p.village("Iilaste", "94112")
    p.village("Sagariste", "94149")
    p.village("Sauaru", "94122")
    p.village("Saue-Putla", "94151")
    p.village("Väike-Rootsi", "94131")
    p.village("Salavere", "94150")
    p.village("Rahniku", "94118")
    p.village("Kangrusselja", "94153")
    p.village("Kailuka", "94127")
    p.village("Ilpla", "94161")
    p.village("Leina", "94115")
    p.village("Liiva-Putla", "94145")
    p.village("Sandla", "94121")

    p.municipality("Torgu", "")
    p.village("Läbara", "")
    p.village("Iide", "")
    p.village("Kaavi", "93239")
    p.village("Lindmetsa", "93243")
    p.village("Mäebe", "")
    p.village("Mõntu", "93122")
    p.village("Lõupõllu", "93245")
    p.village("Mässa", "93247")
    p.village("Sääre", "93249")
    p.village("Maantee", "93121")
    p.village("Soodevahe", "93114")
    p.village("Karuste", "93241")
    p.village("Tammuna", "93250")
    p.village("Jämaja", "93238")
    p.village("Ohessaare", "93248")
    p.village("Kaunispe", "93242")
    p.village("Laadla", "93112")
    p.village("Kargi", "93240")
    p.village("Hänga", "93111")
    p.village("Lülle", "93113")
    p.village("Türju", "93251")

    p.municipality("Mustjala", "")
    p.village("Merise", "")
    p.village("Silla", "")
    p.village("Rahtla", "93614")
    p.village("Kugalepa", "93611")
    p.village("Küdema", "93622")
    p.village("Selgase", "93642")
    p.village("Jauni", "93641")
    p.village("Ohtja", "93623")
    p.village("Tuiu", "93645")
    p.village("Tagaranna", "93616")
    p.village("Kiruma", "93621")
    p.village("Paatsa", "93644")
    p.village("Vanakubja", "93617")
    p.village("Panga", "93634")
    p.village("Pahapilli", "93633")
    p.village("Ninase", "93613")
    p.village("Järise", "93643")
    p.village("Liiküla", "93631")

    p.municipality("Laimjala", "")
    p.village("Rannaküla", "")
    p.village("Aaviku", "94417")
    p.village("Käo", "94434")
    p.village("Mustla", "")
    p.village("Asva", "94418")
    p.village("Üüvere", "94425")
    p.village("Paju-Kurdla", "94415")
    p.village("Saaremetsa", "94443")
    p.village("Audla", "94431")
    p.village("Kapra", "94432")
    p.village("Kõiguste", "94421")
    p.village("Jõe", "")
    p.village("Saareküla", "94442")
    p.village("Mägi-Kurdla", "94412")
    p.village("Ridala", "94416")
    p.village("Pahavalla", "94414")
    p.village("Kahtla", "94420")
    p.village("Kingli", "94433")
    p.village("Viltina", "94424")
    p.village("Ruhve", "94423")

    p.municipality("Muhu", "")
    p.village("Liiva", "")
    p.village("Rinsi", "94761")
    p.village("Vanamõisa", "")
    p.village("Tamse", "94763")
    p.village("Igaküla", "94722")
    p.village("Pallasmaa", "94754")
    p.village("Päelda", "94755")
    p.village("Koguva", "94724")
    p.village("Kantsi", "94723")
    p.village("Lehtmetsa", "94746")
    p.village("Võiküla", "94713")
    p.village("Simisti", "94719")
    p.village("Nautse", "94728")
    p.village("Levalõpme", "94748")
    p.village("Linnuse", "")
    p.village("Mõega", "94711")
    p.village("Kapi", "94743")
    p.village("Raugi", "94759")
    p.village("Mõisaküla", "")
    p.village("Kuivastu", "94702")
    p.village("Külasema", "94744")
    p.village("Leeskopa", "94726")
    p.village("Vahtraste", "94765")
    p.village("Rässa", "94718")
    p.village("Raegma", "94717")
    p.village("Lõetsa", "94749")
    p.village("Pädaste", "94716")
    p.village("Kallaste", "")
    p.village("Kesse", "94720")
    p.village("Pärase", "94756")
    p.village("Lalli", "94745")
    p.village("Oina", "94715")
    p.village("Ridasi", "94731")
    p.village("Soonda", "94762")
    p.village("Tupenurme", "94764")
    p.village("Piiri", "94730")
    p.village("Mäla", "94750")
    p.village("Paenase", "94753")
    p.village("Suuremõisa", "94733")
    p.village("Põitse", "94757")
    p.village("Tusti", "94712")
    p.village("Lepiku", "94747")
    p.village("Hellamaa", "94741")
    p.village("Rootsivere", "94732")
    p.village("Võlla", "94714")
    p.village("Rebaski", "94760")
    p.village("Aljava", "94721")
    p.village("Nõmmküla", "94752")

    p.municipality("Ruhnu", "")




# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.

"""

"""

from __future__ import unicode_literals
from __future__ import print_function

from commondata.utils import Place, PlaceGenerator

class PlaceInEstonia(Place):

    def __unicode__(self):
        return self.name


class Country(PlaceInEstonia):
    value = 0

class County(PlaceInEstonia):
    value = 1
    # maakond

class Municipality(PlaceInEstonia):
    value = 2
    # vald

class Town(Municipality):
    pass
    # linn

class Township(Municipality):
    pass
    # linnaosa

class Village(PlaceInEstonia):
    value = 5
    # küla

class SmallBorough(Village):
    pass
    # alevik

class Borough(SmallBorough):
    pass
    # alev



def root():

    p = PlaceGenerator()
    p.install(Country, County, Town, Township, Municipality, Borough,
              SmallBorough, Village)
    p.set_args('name zip_code')

    eesti = p.country("Eesti")
    
    from .harju import populate ; populate(p)
    from .hiiu import populate ; populate(p)
    from .idaviru import populate ; populate(p)
    from .j6geva import populate ; populate(p)
    from .jarva import populate ; populate(p)
    from .laane import populate ; populate(p)
    from .laaneviru import populate ; populate(p)
    from .p6lva import populate ; populate(p)
    from .parnu import populate ; populate(p)
    from .rapla import populate ; populate(p)
    from .saare import populate ; populate(p)
    from .tartu import populate ; populate(p)
    from .valga import populate ; populate(p)
    from .viljandi import populate ; populate(p)
    from .v6ru import populate ; populate(p)
    
    return eesti


def _test():
    import doctest
    doctest.testmod()

if __name__ == "__main__":
    _test()





# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    
    # Ida-Viru (county)
    p.county("Ida-Viru", "")
    p.municipality("Lohusuu", "")
    p.village("Kalmaküla", "")
    p.village("Ninasi", "42003")
    p.village("Tammispää", "42006")
    p.village("Raadna", "42004")
    p.village("Kärasi", "42119")
    p.village("Piilsi", "42120")
    p.village("Jõemetsa", "42118")
    p.village("Separa", "42005")
    p.village("Vilusi", "42007")

    p.municipality("Sonda", "")
    p.smallborough("Erra", "")
    p.village("Erra-Liiva", "")
    p.village("Varinurme", "")
    p.village("Vana-Sonda", "43006")
    p.village("Uljaste", "43005")
    p.village("Koljala", "43135")
    p.village("Vainu", "43136")
    p.village("Ilmaste", "43138")
    p.village("Nüri", "43003")
    p.village("Satsu", "43004")

    p.municipality("Toila", "")
    p.smallborough("Voka", "")
    p.village("Pühajõe", "")
    p.village("Altküla", "")
    p.village("Konju", "41714")
    p.village("Uikala", "41717")
    p.village("Martsa", "41715")
    p.village("Päite", "40104")
    p.village("Metsamägara", "41712")
    p.village("Vaivina", "40105")

    p.municipality("Tudulinna", "")
    p.village("Sahargu", "")
    p.village("Pikati", "42207")
    p.village("Rannapungerja", "42208")
    p.village("Roostoja", "42209")
    p.village("Peressaare", "42121")
    p.village("Oonurme", "42206")
    p.village("Tagajõe", "42211")
    p.village("Lemmaku", "42205")
    p.village("Kellassaare", "42204")

    p.town("Sillamäe", "")
    p.town("Püssi", "")
    p.municipality("Lüganuse", "")
    p.village("Purtse", "")
    p.village("Matka", "")
    p.village("Moldova", "43307")
    p.village("Irvala", "43132")
    p.village("Mustmätta", "43308")
    p.village("Aa", "43311")
    p.village("Jabara", "43304")
    p.village("Kopli", "43305")
    p.village("Liimala", "43306")
    p.village("Varja", "43309")
    p.village("Voorepera", "43310")
    p.village("Lohkuse", "43225")

    p.municipality("Vaivara", "")
    p.smallborough("Sinimäe", "")
    p.smallborough("Olgina", "")
    p.village("Tõrvajõe", "")
    p.village("Sõtke", "")
    p.village("Hiiemetsa", "40108")
    p.village("Udria", "40118")
    p.village("Soldina", "40115")
    p.village("Vodava", "40119")
    p.village("Perjatsi", "40241")
    p.village("Pimestiku", "40113")
    p.village("Hundinurga", "40109")
    p.village("Auvere", "40107")
    p.village("Arumäe", "40106")
    p.village("Kudruküla", "29024")
    p.village("Mustanina", "40111")
    p.village("Laagna", "40110")
    p.village("Puhkova", "40114")
    p.village("Meriküla", "29025")
    p.village("Peeterristi", "40112")

    p.town("Narva", "")
    p.municipality("Avinurme", "")
    p.village("Paadenurme", "42113")
    p.village("Laekannu", "42110")
    p.village("Tammessaare", "42115")
    p.village("Adraku", "42103")
    p.village("Vadi", "42116")
    p.village("Kiissa", "42106")
    p.village("Kõrve", "42107")
    p.village("Sälliksaare", "42114")
    p.village("Kaevussaare", "42122")
    p.village("Kõrvemetsa", "42108")
    p.village("Maetsma", "42112")
    p.village("Kõveriku", "42109")
    p.village("Alekere", "42104")
    p.village("Lepiksaare", "42111")
    p.village("Änniksaare", "42117")
    p.village("Ulvi", "42102")

    p.town("Narva-Jõesuu", "")
    p.town("Kohtla-Järve", "")
    p.township("Sirgala (Viivikonna linnaosa)", "")
    p.municipality("Aseri", "")
    p.village("Rannu", "")
    p.village("Kestla", "43303")
    p.village("Kõrkküla", "43405")
    p.village("Kõrtsialuse", "43406")
    p.village("Kalvi", "43403")
    p.village("Oru", "43407")
    p.village("Koogu", "43404")
    p.village("Aseriaru", "43402")

    p.town("Jõhvi", "")
    p.village("Puru", "")
    p.village("Linna", "")
    p.smallborough("Tammiku", "")
    p.village("Edise", "")
    p.village("Kotinuka", "")
    p.village("Sompa", "")
    p.village("Pauliku", "")
    p.village("Kahula", "")
    p.village("Pajualuse", "")
    p.village("Pargitaguse", "")
    p.village("Kose", "")

    p.municipality("Iisaku", "")
    p.village("Kuru", "")
    p.village("Tammetaguse", "41112")
    p.village("Sõrumäe", "41111")
    p.village("Jõuga", "41104")
    p.village("Alliku", "41102")
    p.village("Lõpe", "42213")
    p.village("Koldamäe", "41106")
    p.village("Taga-Roostoja", "42203")
    p.village("Kauksi", "41008")
    p.village("Pootsiku", "41109")
    p.village("Kasevälja", "41105")
    p.village("Sälliku", "41110")
    p.village("Varesmetsa", "41115")
    p.village("Lipniku", "41107")
    p.village("Vaikla", "41114")
    p.village("Tärivere", "41113")
    p.village("Imatu", "41103")

    p.town("Kiviõli", "")
    p.municipality("Alajõe", "")
    p.village("Smolnitsa", "")
    p.village("Remniku", "")
    p.village("Vasknarva", "")
    p.village("Katase", "")
    p.village("Karjamaa", "41002")
    p.village("Uusküla", "41006")

    p.municipality("Kohtla-Nõmme", "")
    p.municipality("Maidla", "")
    p.village("Savala", "")
    p.village("Uniküla", "")
    p.village("Soonurme", "")
    p.village("Aidu-Liiva", "")
    p.village("Kulja", "42311")
    p.village("Mehide", "42313")
    p.village("Virunurme", "42324")
    p.village("Rebu", "42317")
    p.village("Tarumaa", "41305")
    p.village("Lümatu", "42312")
    p.village("Aidu", "42302")
    p.village("Aidu-Nõmme", "42304")
    p.village("Koolma", "42310")
    p.village("Arupäälse", "42307")
    p.village("Aidu-Sooküla", "42305")
    p.village("Lipu", "41304")
    p.village("Rääsa", "42318")
    p.village("Salaküla", "43133")
    p.village("Aruküla", "")
    p.village("Sirtsi", "42320")
    p.village("Piilse", "42316")
    p.village("Hirmuse", "42309")
    p.village("Ojamaa", "42315")
    p.village("Veneoja", "42323")
    p.village("Aruvälja", "42308")
    p.village("Oandu", "42314")

    p.municipality("Mäetaguse", "")
    p.village("Kiikla", "")
    p.village("Rajaküla", "")
    p.village("Liivakünka", "41314")
    p.village("Uhe", "41320")
    p.village("Apandiku", "41306")
    p.village("Väike-Pungerja", "41324")
    p.village("Atsalama", "41309")
    p.village("Võhma", "41321")
    p.village("Ratva", "41318")
    p.village("Kalina", "41312")
    p.village("Ereda", "41310")
    p.village("Tarakuse", "41319")
    p.village("Võide", "41322")
    p.village("Metsküla", "41315")
    p.village("Arvila", "41308")
    p.village("Pagari", "41303")
    p.village("Jõetaguse", "41311")
    p.village("Võrnu", "41323")

    p.municipality("Kohtla", "")
    p.village("Roodu", "")
    p.village("Servaääre", "30506")
    p.village("Paate", "30625")
    p.village("Kabelimetsa", "30624")
    p.village("Järve", "30331")
    p.village("Täkumetsa", "30626")
    p.village("Vitsiku", "30507")
    p.village("Ontika", "41556")
    p.village("Saka", "30103")
    p.village("Mõisamaa", "30332")
    p.village("Kukruse", "30623")
    p.village("Amula", "41553")
    p.village("Kaasikaia", "41554")
    p.village("Kaasikvälja", "41555")
    p.village("Peeri", "30333")
    p.village("Valaste", "41557")

    p.municipality("Illuka", "")
    p.village("Kurtna", "")
    p.village("Kuremäe", "")
    p.village("Konsu", "41209")
    p.village("Kivinõmme", "41208")
    p.village("Rausvere", "41214")
    p.village("Karoli", "41011")
    p.village("Permisküla", "41013")
    p.village("Agusalu", "41211")
    p.village("Ohakvere", "41210")
    p.village("Kaatermu", "41205")
    p.village("Puhatu", "41213")
    p.village("Kamarna", "41207")
    p.village("Jaama", "41010")
    p.village("Edivere", "41203")
    p.village("Vasavere", "41215")
    p.village("Kuningaküla", "41012")
    p.village("Kaidma", "41206")
    p.village("Ongassaare", "41212")





# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    
    # Lääne (county)
    p.county("Lääne", "")
    p.town("Lihula", "")
    p.village("Hälvati", "")
    p.village("Tuudi", "")
    p.village("Kirbla", "")
    p.village("Penijõe", "90305")
    p.village("Seira", "90214")
    p.village("Kloostri", "90206")
    p.village("Parivere", "90228")
    p.village("Lautna", "90212")
    p.village("Võhma", "90215")
    p.village("Matsalu", "90230")
    p.village("Petaaluse", "90223")
    p.village("Rumba", "90213")
    p.village("Vagivere", "90226")
    p.village("Metsküla", "90232")
    p.village("Tuhu", "90225")
    p.village("Valuste", "90227")
    p.village("Kirikuküla", "90221")
    p.village("Poanse", "90224")
    p.village("Meelva", "90231")
    p.village("Kelu", "90205")
    p.village("Alaküla", "90219")
    p.village("Kunila", "90222")
    p.village("Pagasi", "90207")
    p.village("Saastna", "90233")
    p.village("Järise", "90220")

    p.municipality("Risti", "")
    p.village("Jaakna", "90911")
    p.village("Kuijõe", "90903")
    p.village("Piirsalu", "90902")
    p.village("Rõuma", "90904")

    p.municipality("Ridala", "")
    p.smallborough("Uuemõisa", "")
    p.smallborough("Paralepa", "")
    p.village("Valgevälja", "")
    p.village("Herjava", "")
    p.village("Tanska", "")
    p.village("Vilkla", "")
    p.village("Rohuküla", "")
    p.village("Nõmme", "")
    p.village("Mäeküla", "")
    p.village("Pusku", "")
    p.village("Kiltsi", "")
    p.village("Sinalepa", "")
    p.village("Saardu", "90424")
    p.village("Lannuste", "90414")
    p.village("Liivaküla", "")
    p.village("Metsaküla", "90436")
    p.village("Allika", "90405")
    p.village("Üsse", "90461")
    p.village("Tuuru", "90426")
    p.village("Põgari-Sassi", "90421")
    p.village("Kiideva", "90409")
    p.village("Rohense", "90457")
    p.village("Tammiku", "")
    p.village("Jõõdre", "90412")
    p.village("Hobulaiu", "90432")
    p.village("Vätse", "90481")
    p.village("Parila", "90418")
    p.village("Emmuvere", "90431")
    p.village("Kadaka", "90455")
    p.village("Väike-Ahli", "90446")
    p.village("Koheri", "90434")
    p.village("Koidu", "90410")
    p.village("Rummu", "90458")
    p.village("Haeska", "90407")
    p.village("Kolila", "90411")
    p.village("Kaevere", "90408")
    p.village("Mägari", "90438")
    p.village("Suure-Ahli", "90443")
    p.village("Aamse", "90450")
    p.village("Käpla", "90413")
    p.village("Erja", "90451")
    p.village("Litu", "90416")
    p.village("Kolu", "90435")
    p.village("Varni", "90445")
    p.village("Puise", "90420")
    p.village("Espre", "90452")
    p.village("Ammuta", "90406")
    p.village("Laheva", "90456")
    p.village("Uneste", "90427")
    p.village("Lõbe", "90417")
    p.village("Sepaküla", "90442")
    p.village("Puiatu", "90419")
    p.village("Kabrametsa", "90454")
    p.village("Saanika", "90423")
    p.village("Võnnu", "90460")
    p.village("Kiviküla", "90433")
    p.village("Panga", "90402")

    p.town("Haapsalu", "")
    p.municipality("Hanila", "")
    p.smallborough("Virtsu", "")
    p.village("Voose", "")
    p.village("Kõmsi", "")
    p.village("Rame", "90127")
    p.village("Rannaküla", "")
    p.village("Massu", "90111")
    p.village("Ullaste", "90117")
    p.village("Pajumaa", "90125")
    p.village("Kokuta", "90108")
    p.village("Vatla", "90103")
    p.village("Karuse", "90112")
    p.village("Mäense", "90113")
    p.village("Linnuse", "90121")
    p.village("Kõera", "90110")
    p.village("Kaseküla", "90106")
    p.village("Esivere", "90104")
    p.village("Ridase", "90131")
    p.village("Äila", "90128")
    p.village("Pivarootsi", "90126")
    p.village("Lõo", "90122")
    p.village("Nehatu", "90123")
    p.village("Kiska", "90120")
    p.village("Kuke", "90109")
    p.village("Kause", "90107")
    p.village("Nurmsi", "90124")
    p.village("Kinksi", "90130")
    p.village("Salevere", "90116")

    p.municipality("Taebla", "")
    p.smallborough("Palivere", "")
    p.village("Luigu", "")
    p.village("Vidruka", "")
    p.village("Nigula", "")
    p.village("Pälli", "")
    p.village("Väänla", "90819")
    p.village("Võntküla", "90820")
    p.village("Allikmaa", "90811")
    p.village("Nihka", "90808")
    p.village("Koela", "90806")
    p.village("Leediküla", "90813")
    p.village("Kedre", "90812")
    p.village("Kadarpiku", "90804")
    p.village("Kirimäe", "90805")
    p.village("Tagavere", "90816")
    p.village("Turvalepa", "90817")

    p.municipality("Oru", "")
    p.village("Linnamäe", "")
    p.village("Saunja", "")
    p.village("Niibi", "91015")
    p.village("Jalukse", "91004")
    p.village("Ingküla", "91003")
    p.village("Soolu", "91012")
    p.village("Auaste", "91002")
    p.village("Seljaküla", "91011")
    p.village("Mõisaküla", "")
    p.village("Kärbla", "91006")
    p.village("Keedika", "91005")
    p.village("Uugla", "91013")
    p.village("Salajõe", "91016")
    p.village("Vedra", "91014")

    p.municipality("Vormsi", "")
    p.village("Hullo", "")
    p.village("Sviby", "91313")
    p.village("Söderby", "91314")
    p.village("Rälby", "91310")
    p.village("Saxby", "91311")
    p.village("Norrby", "91308")
    p.village("Rumpo", "91309")
    p.village("Kersleti", "91307")
    p.village("Förby", "91305")
    p.village("Borrby", "91302")
    p.village("Suuremõisa", "91312")
    p.village("Fällarna", "91304")
    p.village("Diby", "91303")

    p.municipality("Martna", "")
    p.village("Rõude", "")
    p.village("Kaasiku", "")
    p.village("Niinja", "90628")
    p.village("Oonga", "90616")
    p.village("Ehmja", "90620")
    p.village("Uusküla", "90634")
    p.village("Väike-Lähtru", "90636")
    p.village("Soo-otsa", "90646")
    p.village("Enivere", "90621")
    p.village("Keskküla", "90606")
    p.village("Kokre", "90626")
    p.village("Kirna", "90625")
    p.village("Keskvere", "90642")
    p.village("Ohtla", "90630")
    p.village("Tuka", "90617")
    p.village("Kaare", "90640")
    p.village("Putkaste", "90631")
    p.village("Kabeli", "90641")
    p.village("Jõesse", "90622")
    p.village("Laiküla", "90612")
    p.village("Kasari", "90605")
    p.village("Keravere", "90614")
    p.village("Kurevere", "90643")
    p.village("Kuluse", "90627")
    p.village("Suure-Lähtru", "90632")
    p.village("Männiku", "90644")
    p.village("Allikotsa", "90613")
    p.village("Rannajõe", "90645")
    p.village("Kesu", "90624")

    p.municipality("Noarootsi", "")
    p.village("Spithami", "")
    p.village("Pürksi", "")
    p.village("Suur-Nõmmküla", "91232")
    p.village("Saare", "91205")
    p.village("Rooslepa", "91219")
    p.village("Einbi", "91203")
    p.village("Väike-Nõmmküla", "91233")
    p.village("Telise/Tällnäs", "91208")
    p.village("Elbiku", "91202")
    p.village("Paslepa/Pasklepi", "91204")
    p.village("Sutlepa", "91230")
    p.village("Dirhami", "91214")
    p.village("Hosby", "")
    p.village("Vanaküla", "")
    p.village("Aulepa", "91231")
    p.village("Tahu", "91206")
    p.village("Kudani/Gutanäsi", "91216")
    p.village("Hara", "91211")
    p.village("Höbringi", "91213")
    p.village("Tuksi", "91221")
    p.village("Riguldi", "91218")
    p.village("Osmussaare", "91217")
    p.village("Österby", "91207")

    p.municipality("Nõva", "")
    p.village("Hindaste", "91102")
    p.village("Peraküla", "91114")
    p.village("Variku", "91106")
    p.village("Vaisi", "91105")
    p.village("Tusari", "91112")
    p.village("Nõmmemaa", "91103")

    p.municipality("Kullamaa", "")
    p.village("Koluvere", "")
    p.village("Lemmikküla", "90714")
    p.village("Jõgisoo", "90710")
    p.village("Ubasalu", "90719")
    p.village("Kullametsa", "90713")
    p.village("Üdruma", "90720")
    p.village("Silla", "90718")
    p.village("Päri", "90717")
    p.village("Kalju", "90703")
    p.village("Kastja", "90715")
    p.village("Mõrdu", "90716")
    p.village("Leila", "90704")
    p.village("Liivi", "90711")





# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Tartu (county)
    p.county("Tartu", "")
    p.town("Tartu", "")
    p.smallborough("Kõrveküla", "")
    p.smallborough("Vahi", "")
    p.village("Lombi", "")
    p.smallborough("Lähte", "")
    p.village("Maramaa", "")
    p.village("Tila", "")
    p.village("Haava", "")
    p.village("Aovere", "")
    p.village("Vasula", "")
    p.village("Vesneri", "")
    p.smallborough("Äksi", "")
    p.village("Kastli", "60508")
    p.village("Salu", "60525")
    p.village("Soitsjärve", "60527")
    p.village("Sojamaa", "60528")
    p.village("Igavere", "60506")
    p.village("Jõusa", "60507")
    p.village("Võibla", "60540")
    p.village("Pupastvere", "60523")
    p.village("Kobratu", "60510")
    p.village("Väägvere", "60541")
    p.village("Kukulinna", "60511")
    p.village("Tammistu", "60531")
    p.village("Õvi", "60542")
    p.village("Kükitaja", "60514")
    p.village("Vedu", "60536")
    p.village("Arupää", "60504")
    p.village("Sootaga", "60529")
    p.village("Erala", "60505")
    p.village("Toolamaa", "60533")
    p.village("Kikivere", "60509")
    p.village("Viidike", "60538")
    p.village("Nõela", "60521")
    p.village("Lammiku", "60515")
    p.village("Möllatsi", "60519")
    p.village("Puhtaleiva", "60522")
    p.village("Saadjärve", "60524")
    p.village("Vilussaare", "60539")
    p.village("Kärkna", "60513")
    p.village("Soeküla", "60526")
    p.village("Metsanuka", "60518")
    p.village("Nigula", "60520")
    p.village("Taabri", "60530")

    p.municipality("Luunja", "")
    p.village("Lohkva", "")
    p.village("Veibri", "")
    p.village("Kabina", "")
    p.village("Rõõmu", "")
    p.village("Kakumetsa", "")
    p.village("Põvvatu", "")
    p.village("Sava", "62214")
    p.village("Pajukurmu", "62209")
    p.village("Savikoja", "62215")
    p.village("Pilka", "")
    p.village("Poksi", "62211")
    p.village("Sääsekõrva", "62218")
    p.village("Kikaste", "62205")
    p.village("Kõivu", "62206")
    p.village("Sirgumetsa", "62217")
    p.village("Viira", "62221")
    p.village("Muri", "62208")
    p.village("Kavastu", "62204")
    p.village("Sääsküla", "62219")
    p.village("Sirgu", "62216")

    p.municipality("Ülenurme", "")
    p.smallborough("Tõrvandi", "")
    p.village("Soinaste", "")
    p.village("Räni", "")
    p.village("Laane", "")
    p.village("Külitse", "")
    p.village("Lemmatsi", "")
    p.village("Uhti", "")
    p.village("Õssu", "")
    p.village("Reola", "")
    p.village("Lepiku", "")
    p.village("Soosilla", "61710")
    p.village("Läti", "61706")
    p.village("Täsvere", "61711")

    p.municipality("Haaslava", "")
    p.smallborough("Roiu", "")
    p.village("Aardlapalu", "")
    p.village("Tõõraste", "")
    p.village("Aardla", "")
    p.village("Mõra", "")
    p.village("Lange", "")
    p.village("Aadami", "")
    p.village("Ignase", "")
    p.village("Kõivuküla", "")
    p.village("Koke", "62111")
    p.village("Kurepalu", "")
    p.village("Igevere", "62108")
    p.village("Päkste", "62119")
    p.village("Alaküla", "62106")
    p.village("Kitseküla", "62110")
    p.village("Paluküla", "62118")
    p.village("Uniküla", "62121")
    p.village("Metsanurga", "62116")

    p.municipality("Rõngu", "")
    p.smallborough("Käärdi", "")
    p.village("Teedla", "")
    p.village("Kalme", "")
    p.village("Raigaste", "")
    p.village("Valguta", "")
    p.village("Uderna", "")
    p.village("Lapetukme", "")
    p.village("Rannaküla", "61012")
    p.village("Kirepi", "61003")
    p.village("Lossimäe", "61009")
    p.village("Tammiste", "61013")
    p.village("Koruste", "61004")
    p.village("Piigandi", "61010")
    p.village("Käo", "61006")
    p.village("Tilga", "61015")
    p.village("Kõduküla", "61005")

    p.municipality("Kambja", "")
    p.village("Sulu", "")
    p.village("Pangodi", "")
    p.village("Visnapuu", "")
    p.village("Virulase", "")
    p.village("Vana-Kuuste", "")
    p.village("Madise", "")
    p.village("Kullaga", "62009")
    p.village("Kodijärve", "62008")
    p.village("Sirvaku", "62025")
    p.village("Kõrkküla", "62010")
    p.village("Mäeküla", "62013")
    p.village("Pühi", "62019")
    p.village("Raanitsa", "62020")
    p.village("Aakaru", "")
    p.village("Oomiste", "")
    p.village("Sipe", "62024")
    p.village("Kavandu", "62032")
    p.village("Reolasoo", "62022")
    p.village("Ivaste", "62005")
    p.village("Paali", "62015")
    p.village("Tatra", "62029")
    p.village("Pulli", "62018")
    p.village("Talvikese", "62028")
    p.village("Riiviku", "62023")
    p.village("Kammeri", "62007")
    p.village("Palumäe", "62016")
    p.village("Rebase", "62021")
    p.village("Lalli", "62011")
    p.village("Suure-Kambja", "62027")
    p.village("Kaatsi", "62006")

    p.town("Elva", "")
    p.municipality("Nõo", "")
    p.smallborough("Tõravere", "")
    p.village("Luke", "")
    p.village("Meeri", "")
    p.village("Tamsa", "")
    p.village("Nõgiaru", "")
    p.village("Etsaste", "")
    p.village("Vissi", "")
    p.village("Uuta", "61620")
    p.village("Ketneri", "61610")
    p.village("Altmäe", "61604")
    p.village("Kääni", "61612")
    p.village("Voika", "")
    p.village("Aiamaa", "61603")
    p.village("Laguja", "61613")
    p.village("Kolga", "61611")
    p.village("Enno", "61605")
    p.village("Sassi", "61617")
    p.village("Keeri", "61609")
    p.village("Unipiha", "61619")
    p.village("Järiste", "61608")

    p.town("Kallaste", "")
    p.municipality("Puhja", "")
    p.smallborough("Ulila", "")
    p.village("Võsivere", "")
    p.village("Tännassilma", "")
    p.village("Teilma", "")
    p.village("Rämsi", "")
    p.village("Võllinge", "61318")
    p.village("Mõisanurme", "61307")
    p.village("Saare", "")
    p.village("Järvaküla", "61304")
    p.village("Mäeselja", "61308")
    p.village("Poriküla", "61311")
    p.village("Vihavu", "61317")
    p.village("Ridaküla", "61312")
    p.village("Kaimi", "61305")
    p.village("Nasja", "61309")
    p.village("Palupõhja", "60547")
    p.village("Härjanurme", "61303")

    p.municipality("Alatskivi", "")
    p.village("Savimetsa", "60226")
    p.village("Linaleo", "60210")
    p.village("Sudemäe", "60227")
    p.village("Virtsu", "60231")
    p.village("Rupsi", "60223")
    p.village("Savastvere", "60225")
    p.village("Tõruvere", "60230")
    p.village("Orgemäe", "60213")
    p.village("Lahe", "60208")
    p.village("Rootsiküla", "60222")
    p.village("Nina", "60212")
    p.village("Pusi", "60217")
    p.village("Kõdesi", "60207")
    p.village("Ronisoo", "60221")
    p.village("Lahepera", "60209")
    p.village("Toruküla", "60229")
    p.village("Päiksi", "60218")
    p.village("Passi", "60215")
    p.village("Padakõrve", "60214")
    p.village("Kesklahe", "60204")
    p.village("Naelavere", "60211")
    p.village("Kokora", "60205")
    p.village("Alasoo", "60202")
    p.village("Pärsikivi", "60219")
    p.village("Peatskivi", "60216")
    p.village("Torila", "60228")
    p.village("Haapsipea", "60203")
    p.village("Saburi", "60224")
    p.village("Väljaküla", "60232")
    p.village("Riidma", "60220")
    p.village("Kuningvere", "60206")

    p.municipality("Mäksa", "")
    p.village("Melliste", "")
    p.village("Sudaste", "62310")
    p.village("Võõpste", "62316")
    p.village("Tigase", "62312")
    p.village("Kastre", "62305")
    p.village("Tammevaldma", "62311")
    p.village("Veskimäe", "62314")
    p.village("Sarakuste", "62309")
    p.village("Aruaia", "62303")
    p.village("Mäletjärve", "62307")
    p.village("Vana-Kastre", "62313")
    p.village("Kaagvere", "62317")
    p.village("Kaarlimõisa", "62304")
    p.village("Poka", "62308")
    p.village("Võruküla", "62315")

    p.municipality("Tähtvere", "")
    p.smallborough("Märja", "")
    p.village("Pihva", "")
    p.village("Kandiküla", "")
    p.village("Rahinge", "")
    p.village("Tüki", "")
    p.village("Ilmatsalu", "")
    p.village("Rõhu", "")
    p.village("Vorbuse", "")
    p.village("Haage", "")
    p.village("Kardla", "")

    p.municipality("Konguta", "")
    p.village("Annikoru", "")
    p.village("Metsalaane", "")
    p.village("Pööritsa", "61214")
    p.village("Kurelaane", "61206")
    p.village("Külaaseme", "61207")
    p.village("Poole", "61213")
    p.village("Mäeotsa", "61211")
    p.village("Kapsta", "61203")
    p.village("Vahessaare", "61215")
    p.village("Lembevere", "61208")
    p.village("Mälgi", "61212")
    p.village("Karijärve", "61204")
    p.village("Majala", "61209")
    p.village("Vellavere", "61216")
    p.village("Kobilu", "61205")

    p.municipality("Rannu", "")
    p.village("Tamme", "")
    p.village("Koopsi", "61106")
    p.smallborough("Kureküla", "")
    p.village("Utukolga", "61115")
    p.village("Järveküla", "61103")
    p.village("Sangla", "61112")
    p.village("Noorma", "61110")
    p.village("Vallapalu", "61116")
    p.village("Kaarlijärve", "61104")
    p.village("Kulli", "61107")
    p.village("Suure-Rakke", "61113")
    p.village("Ervu", "61102")
    p.village("Väike-Rakke", "61119")
    p.village("Paju", "61111")
    p.village("Verevi", "61118")
    p.village("Kipastu", "61105")

    p.municipality("Laeva", "")
    p.village("Kärevere", "")
    p.village("Siniküla", "")
    p.village("Valmaotsa", "60605")
    p.village("Kämara", "60602")
    p.village("Väänikvere", "60606")

    p.municipality("Võnnu", "")
    p.village("Hammaste", "62404")
    p.village("Imste", "62405")
    p.village("Kannu", "62407")
    p.village("Agali", "62402")
    p.village("Ahunapalu", "62414")
    p.village("Terikeste", "62413")
    p.village("Kurista", "62408")
    p.village("Rookse", "62412")
    p.village("Lääniste", "62411")
    p.village("Issaku", "62406")
    p.village("Kõnnu", "62409")
    p.village("Liispõllu", "62410")

    p.municipality("Peipsiääre", "")
    p.smallborough("Varnja", "")
    p.smallborough("Kolkja", "")
    p.village("Savka", "60303")
    p.smallborough("Kasepää", "60302")
    p.village("Sipelga", "60304")

    p.municipality("Meeksi", "")
    p.smallborough("Mehikoorma", "")
    p.village("Haavametsa", "62504")
    p.village("Rõka", "62509")
    p.village("Järvselja", "62506")
    p.village("Aravu", "62503")
    p.village("Sikakurmu", "62510")
    p.village("Meerapalu", "62502")
    p.village("Jõepera", "62505")
    p.village("Parapalu", "62508")

    p.municipality("Vara", "")
    p.village("Keressaare", "")
    p.village("Koosa", "")
    p.village("Põrgu", "60418")
    p.village("Rehemetsa", "60419")
    p.village("Kusma", "60408")
    p.village("Põdra", "60416")
    p.village("Sookalduse", "60421")
    p.village("Matjama", "60431")
    p.village("Koosalaane", "60407")
    p.village("Vanaussaia", "60425")
    p.village("Praaga", "60415")
    p.village("Selgise", "60420")
    p.village("Pilpaküla", "60414")
    p.village("Tähemaa", "60423")
    p.village("Meoma", "60410")
    p.village("Särgla", "60422")
    p.village("Mustametsa", "60412")
    p.village("Undi", "60424")
    p.village("Metsakivi", "60411")
    p.village("Kuusiku", "60409")
    p.village("Kargaja", "60404")
    p.village("Alajõe", "60403")
    p.village("Kauda", "60405")
    p.village("Põldmaa", "60417")
    p.village("Välgi", "60427")
    p.village("Ätte", "60428")
    p.village("Papiaru", "60413")

    p.municipality("Piirissaare", "")
    p.village("Piiri", "")
    p.village("Tooni", "62603")

    p.municipality("Vehendi", "")
    p.municipality("Kriimani", "")
    p.municipality("Illi", "")
    p.municipality("Neemisküla", "")




# -*- coding: UTF-8 -*-
# Copyright 2014 Luc Saffre
# This file is part of the commondata library.
# The commondata library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3 of
# the License, or (at your option) any later version.
# The commondata library is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with the commondata library; if not, see
# <http://www.gnu.org/licenses/>.


from __future__ import unicode_literals


def populate(p):

    # Pärnu (county)
    p.county("Pärnu", "")
    p.municipality("Halinga", "")
    p.village("Libatse", "")
    p.borough("Pärnu-Jaagupi", "")
    p.village("Tõrdu", "")
    p.village("Pitsalu", "87230")
    p.village("Rukkiküla", "87233")
    p.village("Kodesmaa", "87217")
    p.village("Salu", "87234")
    p.village("Mäeküla", "87225")
    p.village("Helenurme", "87213")
    p.village("Altküla", "87204")
    p.village("Anelema", "87205")
    p.village("Kuninga", "87218")
    p.village("Arase", "87206")
    p.village("Tarva", "")
    p.village("Kablima", "87214")
    p.village("Oese", "87227")
    p.village("Valistre", "87242")
    p.village("Vakalepa", "87241")
    p.village("Sepaküla", "87235")
    p.village("Enge", "87210")
    p.village("Vahenurme", "87101")
    p.village("Pereküla", "87229")
    p.village("Sõõrike", "87237")
    p.village("Vee", "87243")
    p.village("Ertsma", "87211")
    p.village("Maima", "87223")
    p.village("Mõisaküla", "87224")
    p.village("Kaelase", "87215")
    p.village("Roodi", "87232")
    p.village("Pallika", "87228")
    p.village("Loomse", "87222")
    p.village("Lehtmetsa", "87220")
    p.village("Langerma", "87219")
    p.village("Lehu", "87221")
    p.village("Kangru", "87216")
    p.village("Tühjasma", "87240")
    p.village("Eense", "87208")
    p.village("Soosalu", "87236")
    p.village("Aasa", "87203")
    p.village("Eerma", "87209")
    p.village("Pööravere", "87231")
    p.village("Naartse", "87226")

    p.municipality("Tootsi", "")
    p.municipality("Vändra", "")
    p.village("Vihtra", "")
    p.village("Võidula", "")
    p.village("Kergu", "")
    p.village("Suurejõe", "")
    p.village("Kaisma", "")
    p.village("Viluvere", "87633")
    p.village("Rahnoja", "87622")
    p.village("Luuri", "87614")
    p.village("Kullimaa", "87611")
    p.village("Ünnaste", "87636")
    p.village("Kobra", "87609")
    p.village("Massu", "87616")
    p.village("Rõusa", "87624")
    p.village("Allikõnnu", "87604")
    p.village("Oriküla", "87619")
    p.village("Kalmaru", "87607")
    p.village("Kirikumõisa", "87608")
    p.village("Kurgja", "87612")
    p.village("Metsavere", "87405")
    p.village("Veskisoo", "87632")
    p.village("Leetva", "87613")
    p.village("Tagassaare", "87629")
    p.village("Lüüste", "87615")
    p.village("Rätsepa", "")
    p.village("Aluste", "87601")
    p.village("Rae", "87621")
    p.village("Kose", "87610")
    p.village("Pärnjõe", "87620")
    p.village("Reinumurru", "87623")
    p.village("Rahkama", "87406")
    p.village("Sikana", "87627")
    p.village("Kaansoo", "87605")
    p.village("Võiera", "87635")
    p.village("Kõnnu", "87403")
    p.village("Venekuusiku", "87631")
    p.village("Sohlu", "87407")
    p.village("Säästla", "87628")
    p.village("Samliku", "87626")
    p.village("Kadjaste", "87606")
    p.village("Vaki", "87630")
    p.village("Mustaru", "87617")
    p.village("Mädara", "87618")

    p.municipality("Tori", "")
    p.village("Jõesuu", "")
    p.village("Piistaoja", "")
    p.village("Kõrsa", "")
    p.village("Selja", "")
    p.village("Taali", "")
    p.village("Urumarja", "")
    p.village("Kildemaa", "86805")
    p.village("Oore", "86812")
    p.village("Elbi", "86804")
    p.village("Aesoo", "86803")
    p.village("Muti", "86811")
    p.village("Riisa", "86815")
    p.village("Levi", "86808")
    p.village("Kuiaru", "86806")
    p.village("Muraka", "86810")
    p.village("Tohera", "86819")
    p.village("Mannare", "86809")
    p.village("Randivälja", "86814")
    p.village("Võlli", "86821")

    p.municipality("Tõstamaa", "")
    p.village("Kiraste", "88108")
    p.village("Lao", "88110")
    p.village("Pootsi", "88115")
    p.village("Tõlli", "88119")
    p.village("Rammuka", "88117")
    p.village("Ranniku", "88118")
    p.village("Lõuka", "88111")
    p.village("Tõhela", "88102")
    p.village("Seliste", "88103")
    p.village("Peerni", "88114")
    p.village("Kastna", "88106")
    p.village("Alu", "88104")
    p.village("Ermistu", "88105")
    p.village("Kavaru", "88107")
    p.village("Värati", "88120")
    p.village("Männikuste", "88113")
    p.village("Päraküla", "88116")
    p.village("Manija", "88112")
    p.village("Kõpu", "88109")

    p.municipality("Tahkuranna", "")
    p.village("Reiu", "")
    p.village("Uulu", "")
    p.smallborough("Võiste", "")
    p.village("Lepaküla", "")
    p.village("Laadi", "")
    p.village("Piirumi", "86507")
    p.village("Metsaküla", "")
    p.village("Leina", "86504")

    p.municipality("Sauga", "")
    p.village("Tammiste", "")
    p.village("Kilksama", "")
    p.village("Eametsa", "")
    p.village("Nurme", "")
    p.village("Urge", "")
    p.village("Vainu", "")
    p.village("Räägu", "85006")
    p.village("Kiisa", "85002")
    p.village("Rütavere", "85007")
    p.village("Pulli", "85005")

    p.municipality("Paikuse", "")
    p.village("Silla", "")
    p.village("Seljametsa", "")
    p.village("Tammuru", "")
    p.village("Põlendmaa", "86603")
    p.village("Vaskrääma", "86606")

    p.town("Pärnu", "")
    p.town("Sindi", "")
    p.municipality("Audru", "")
    p.village("Kõima", "")
    p.village("Papsaare", "")
    p.village("Lemmetsa", "")
    p.village("Liiva", "")
    p.village("Malda", "")
    p.village("Marksa", "")
    p.village("Kihlepa", "")
    p.village("Lindi", "")
    p.village("Jõõpre", "")
    p.village("Kabriste", "")
    p.village("Põldeotsa", "")
    p.village("Saulepa", "")
    p.village("Valgeranna", "")
    p.village("Ahaste", "")
    p.village("Oara", "88316")
    p.village("Soeva", "88323")
    p.village("Tuuraste", "88325")
    p.village("Saari", "88321")
    p.village("Soomra", "")
    p.village("Kärbu", "88310")
    p.village("Põhara", "88318")
    p.village("Liu", "88313")
    p.village("Eassalu", "88307")
    p.village("Ridalepa", "88320")

    p.municipality("Häädemeeste", "")
    p.village("Kabli", "")
    p.village("Rannametsa", "86016")
    p.village("Papisilla", "86013")
    p.village("Penu", "86014")
    p.village("Metsapoole", "86010")
    p.village("Orajõe", "86012")
    p.village("Urissaare", "86019")
    p.village("Arumetsa", "86006")
    p.village("Sooküla", "86017")
    p.village("Massiaru", "86004")
    p.village("Majaka", "")
    p.village("Soometsa", "86018")
    p.village("Krundiküla", "86008")
    p.village("Võidu", "86021")
    p.village("Uuemaa", "86020")
    p.village("Pulgoja", "86015")
    p.village("Jaagupi", "86007")
    p.village("Ikla", "86005")
    p.village("Nepste", "86011")
    p.village("Treimani", "86003")

    p.town("Kilingi-Nõmme", "")
    p.municipality("Are", "")
    p.village("Kurena", "")
    p.village("Parisselja", "87308")
    p.village("Suigu", "87302")
    p.village("Elbu", "87304")
    p.village("Niidu", "87307")
    p.village("Pärivere", "87309")
    p.village("Tabria", "87311")
    p.village("Lepplaane", "87306")
    p.village("Murru", "87310")
    p.village("Eavere", "87303")
    p.village("Võlla", "87312")

    p.municipality("Lavassaare", "")
    p.municipality("Varbla", "")
    p.village("Käru", "88217")
    p.village("Kidise", "88212")
    p.village("Saare", "88231")
    p.village("Paatsalu", "88204")
    p.village("Sookalda", "88233")
    p.village("Maade", "88218")
    p.village("Kilgi", "88213")
    p.village("Tiilima", "88235")
    p.village("Matsi", "88219")
    p.village("Koeri", "88214")
    p.village("Ännikse", "88240")
    p.village("Korju", "88215")
    p.village("Õhu", "88239")
    p.village("Tõusi", "88236")
    p.village("Piha", "88225")
    p.village("Täpsi", "88237")
    p.village("Mõtsu", "88222")
    p.village("Raheste", "88227")
    p.village("Paadrema", "88202")
    p.village("Kulli", "88216")
    p.village("Mereäärse", "88220")
    p.village("Raespa", "88226")
    p.village("Aruküla", "88206")
    p.village("Helmküla", "88208")
    p.village("Hõbesalu", "88209")
    p.village("Rauksi", "88229")
    p.village("Muriste", "88221")
    p.village("Mäliküla", "88223")
    p.village("Kanamardi", "88211")
    p.village("Saulepi", "88203")
    p.village("Tamba", "88234")
    p.village("Vaiste", "88238")
    p.village("Haapsi", "88207")
    p.village("Rädi", "88230")
    p.village("Allika", "88205")
    p.village("Rannaküla", "88228")
    p.village("Kadaka", "88210")
    p.village("Nõmme", "88224")

    p.municipality("Saarde", "")
    p.smallborough("Tihemetsa", "")
    p.village("Veelikse", "")
    p.village("Tõlla", "")
    p.village("Tali", "")
    p.village("Tuuliku", "86108")
    p.village("Sigaste", "86214")
    p.village("Reinu", "86107")
    p.village("Leipste", "86209")
    p.village("Kalita", "86206")
    p.village("Marina", "86105")
    p.village("Jäärja", "86205")
    p.village("Laiksaare", "86103")
    p.village("Väljaküla", "86215")
    p.village("Mustla", "86212")
    p.village("Viisireiu", "86109")
    p.village("Pihke", "86106")
    p.village("Kamali", "86207")
    p.village("Lodja", "86210")
    p.village("Lanksaare", "86104")
    p.village("Marana", "86211")
    p.village("Kanaküla", "86204")
    p.village("Kärsu", "86208")
    p.village("Oissaare", "86216")

    p.municipality("Surju", "")
    p.village("Kalda", "")
    p.village("Ristiküla", "86410")
    p.village("Jaamaküla", "86403")
    p.village("Lähkma", "86407")
    p.village("Kikepera", "86405")
    p.village("Rabaküla", "86409")
    p.village("Kõveri", "86406")
    p.village("Saunametsa", "86411")
    p.village("Ilvese", "86402")

    p.municipality("Kihnu", "")
    p.village("Linaküla", "")
    p.village("Lemsi", "88002")
    p.village("Sääre", "88005")
    p.village("Rootsiküla", "88004")

    p.municipality("Koonga", "")
    p.village("Võrungi", "88441")
    p.village("Tamme", "88434")
    p.village("Ura", "88436")
    p.village("Paimvere", "88425")
    p.village("Irta", "88407")
    p.village("Pikavere", "88430")
    p.village("Peantse", "88428")
    p.village("Kibura", "88415")
    p.village("Vastaba", "88438")
    p.village("Iska", "88408")
    p.village("Kurese", "88418")
    p.village("Nätsi", "88424")
    p.village("Sookatse", "88433")
    p.village("Jänistvere", "88410")
    p.village("Järve", "88411")
    p.village("Tõitse", "88435")
    p.village("Joonuse", "88409")
    p.village("Urita", "88437")
    p.village("Õepa", "88442")
    p.village("Karuba", "88414")
    p.village("Võitra", "88440")
    p.village("Kuhu", "88417")
    p.village("Emmu", "88405")
    p.village("Kiisamaa", "88416")
    p.village("Rabavere", "88431")
    p.village("Palatu", "88426")
    p.village("Nedrema", "88423")
    p.village("Oidrema", "88404")
    p.village("Naissoo", "88422")
    p.village("Kalli", "88412")
    p.village("Veltsa", "88439")
    p.village("Hõbeda", "88406")
    p.village("Salevere", "88432")
    p.village("Mihkli", "88421")
    p.village("Maikse", "88420")
    p.village("Piisu", "88429")
    p.village("Karinõmme", "88413")
    p.village("Parasmaa", "88427")
    p.village("Lõpe", "88402")

    p.municipality("Metsaääre", "")
    p.municipality("Aruvälja", "")

